<?php
/**
 * Widget for Social Stream Designer Pro suppprt.
 *
 * @link       https://www.solwininfotech.com/
 * @since      1.0.0
 *
 * @package    Blog_Designer_PRO
 * @subpackage Blog_Designer_PRO/admin
 * @author     Solwin Infotech <info@solwininfotech.com>
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Social Stream Designer PRO Widget Functions Class.
 *
 * @class   Bdp_Utility
 * @version 1.0.0
 */
class Social_Stream_Designer_Pro_Widget extends WP_Widget {
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		parent::__construct(
			'social_stream_designer_pro_widget',
			esc_html__( 'Social Stream Designer PRO', 'blog-designer-pro' ),
			array(
				'classname'   => 'widgte_social_stream_designer_pro_shortcode_list',
				'description' => esc_html__(
					'Show socil feed of Social Stream Designer Pro. Please use this widget only for full width container area.',
					'blog-designer-pro'
				),
			)
		);
		$this->alt_option_name = 'widgte_social_stream_designer_pro_shortcode_list';
		add_action( 'save_post', array( $this, 'flush_widgte_social_stream_designer_pro_shortcode_list' ) );
		add_action( 'deleted_post', array( $this, 'flush_widgte_social_stream_designer_pro_shortcode_list' ) );
		add_action( 'switch_theme', array( $this, 'flush_widgte_social_stream_designer_pro_shortcode_list' ) );
		// add_action( 'init', array( &$this, 'flush_widgte_blog_designer_pro_css' ) );
	}
	/**
	 * Flush widgte CSS
	 *
	 * @since 2.0
	 * @return void
	 */
	public function flush_widgte_blog_designer_pro_css() {
		if ( ! is_admin() ) {
			$fontawesome_icon_url = BLOGDESIGNERPRO_URL . '/public/css/font-awesome.min.css';
			wp_enqueue_style( 'bdp-widget-fontawesome-stylesheets', $fontawesome_icon_url, null, '4.5' );
		}
	}
	/**
	 * Widget
	 *
	 * @since 2.0
	 * @param array  $args args.
	 * @param strign $instance instance.
	 * @return void
	 */
	public function widget( $args, $instance ) { // phpcs:disable
		$social_stream_designer_pro_shortcode_list = ( isset( $instance['social_stream_designer_pro_shortcode_list'] ) && '' != $instance['social_stream_designer_pro_shortcode_list'] ) ? (int) ( $instance['social_stream_designer_pro_shortcode_list'] ) : '';
		$title                            = ! empty( $instance['title'] ) ? $instance['title'] : '';
		$before_widget                    = $args['before_widget'];
		$after_widget                     = $args['after_widget'];
		if ( $social_stream_designer_pro_shortcode_list ) {
			
		}
		echo $before_widget; //phpcs:ignore
		echo '<h2 class="widget-title">' . esc_html( $title ) . '</h2>';
		echo do_shortcode( '[social_stream_feeds id=' . "$social_stream_designer_pro_shortcode_list" . ']' );
		echo $after_widget; //phpcs:ignore
	}
	/**
	 * Form
	 *
	 * @since 2.0
	 * @param string $instance instance.
	 * @return void
	 */
	public function form( $instance ) {
		$social_stream_designer_pro_shortcode_list = isset( $instance['social_stream_designer_pro_shortcode_list'] ) ? $instance['social_stream_designer_pro_shortcode_list'] : '';
		$title                            = ! empty( $instance['title'] ) ? $instance['title'] : '';
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'blog-designer-pro' ); ?>:</label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<p>
			<label for="social_stream_designer_pro_shortcode_list"><?php esc_html_e( 'Select Blog Layout', 'blog-designer-pro' ); ?>:</label>
			<select name="<?php echo esc_attr( $this->get_field_name( 'social_stream_designer_pro_shortcode_list' ) ); ?>" class="social_stream_designer_pro_shortcode_list" id="social_stream_designer_pro_shortcode_list" style="width:100%">
				<option value="">-- <?php esc_html_e( 'Select Blog Layout', 'blog-designer-pro' ); ?> --</option>
				<?php
				global $wpdb;
				$shortcodes = $wpdb->get_results( 'SELECT * FROM ' . $wpdb->prefix . 'ssd_shortcodes ' ); //phpcs:ignore
				if ( $shortcodes ) {
					foreach ( $shortcodes as $shortcode ) {
						$shortcode_name = $shortcode->shortcode_name;
						?>
						<option value="<?php echo esc_attr( $shortcode->ID ); ?>" 
							<?php
							if ( $social_stream_designer_pro_shortcode_list == $shortcode->ID ) { //phpcs:ignore
								echo 'selected=selected';
							}
							?>
						>
						<?php
						if ( $shortcode_name ) {
							echo esc_html( $shortcode_name );
						} else {
							esc_html_e( 'No title', 'blog-designer-pro' );
						}
						?>
						</option>
						<?php
					}
				}
				?>
			</select>
		</p>
		<?php
	}
	/**
	 * Update
	 *
	 * @since 2.0
	 * @param string $new_instance new instance.
	 * @param string $old_instance old instance.
	 * @return $instance
	 */
	public function update( $new_instance, $old_instance ) {
		$instance                                     = array();
		$instance['title']                            = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : ''; //phpcs:ignore
		$instance['social_stream_designer_pro_shortcode_list'] = ( ! empty( $new_instance['social_stream_designer_pro_shortcode_list'] ) ) ? (int) ( $new_instance['social_stream_designer_pro_shortcode_list'] ) : '';
		$alloptions                                   = wp_cache_get( 'alloptions', 'options' );
		if ( isset( $alloptions['widgte_social_stream_designer_pro_shortcode_list'] ) ) {
			delete_option( 'widgte_social_stream_designer_pro_shortcode_list' );
		}
		return $instance;
	}
	/**
	 * Flush Widget Shortocde List
	 *
	 * @since 2.0
	 * @return void
	 */
	public function flush_widgte_social_stream_designer_pro_shortcode_list() {
		wp_cache_delete( 'widgte_social_stream_designer_pro_shortcode_list', 'widget' );
	}

}
/**
 * Register Blog Designer Widget
 *
 * @return void
 */
function register_social_stream_designer_widget() {
	register_widget( 'Social_Stream_Designer_Pro_Widget' );
}
add_action( 'widgets_init', 'register_social_stream_designer_widget' );
