<?php
/**
 * Flicker Social media class file get all social feed
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get Flickr stream data
 *
 * @package    Social Stream Designer
 * @subpackage Social Stream Designer/admin/assets/feeds
 * @author     Solwin Infotech <support@solwininfotech.com>
 */
class SSDAdminflickrFeeds {
	/**
	 * Table name
	 *
	 * @var string
	 */
	public $feed_posts_table = '';
	/**
	 * Feed Object
	 *
	 * @var string
	 */
	public $feeds_object = '';
	/**
	 * Feed Details
	 *
	 * @var string
	 */
	public $feed_detail = '';
	/**
	 * Feed Id
	 *
	 * @var int
	 */
	public $feed_id = '';
	/**
	 * Page
	 *
	 * @var int
	 */
	public $page = 1;
	/**
	 * Flicker Feed
	 *
	 * @var array
	 */
	public $flickr_feeds = array();
	/**
	 * Post Feeds
	 *
	 * @var array
	 */
	public $post_feeds = array();
	/**
	 * Count Feed Limit
	 *
	 * @var int
	 */
	public $ssd_feed_limit_count = '0';
	/**
	 * Initial set up
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function init() {
		global $wpdb;
		$this->feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		if ( isset( $_POST['feed_stream_nonce'] ) ) {
			if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
				if ( isset( $_REQUEST['action'] ) && 'edit' === $_REQUEST['action'] && isset( $_REQUEST['id'] ) && '' != $_REQUEST['id'] ) {
					$this->feed_id = sanitize_text_field( wp_unslash( $_REQUEST['id'] ) );
				}
			}
		}
		$feed_detail       = $this->ssd_get_feed_detail();
		$this->feed_detail = $feed_detail;
	}
	/**
	 * Get feed type from feed id.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_feed_detail() {
		global $wpdb;
		$feed_id      = $this->feed_id;
		$result_feeds = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
		if ( $result_feeds ) {
			$feeds_settings  = $result_feeds->feeds_settings;
			$feeds_settings  = maybe_unserialize( $feeds_settings );
			$this->feed_type = $feeds_settings['feed'];
			return $feeds_settings;
		} else {
			return '';
		}
	}
	/**
	 * Get all Feeds.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_flickr_stream_from_feed() {
		$feed_detail      = $this->feed_detail;
		$feed_type_flickr = $feed_detail['feed_type_flickr'];
		$feed_limit       = $feed_detail['feed_limit'];
		$user_id          = $feed_detail['flickr_user_id'];
		$flickr_stream    = get_option( 'flickr_stream' );
		include_once SOCIALSTREAMDESIGNER_DIR . '/include/phpFlickr.php';
		$api_key    = $flickr_stream['api_key'];
		$api_secret = $flickr_stream['api_secret'];
		if ( '' == $api_key || '' == $api_secret ) {
			return new WP_Error( 'Missing Authentication. Please Check Authentication Setting', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' User ID' ) );
		}
		if ( '' == $user_id ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' User ID' ) );
		}
		$flickr_obj = new phpFlickr( $api_key, $api_secret, true );
		$user_url   = $flickr_obj->people_getInfo( $user_id );
		
		if ( 'tag' === $feed_type_flickr ) {
			$tags = $feed_detail['flickr_tag_keyword'];
			if ( '' == $tags ) {
				return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Tags' ) );
			}
			if ( $feed_limit < 100 ) {
				$per_page = $feed_limit;
			} else {
				$per_page = 100;
			}
			$url       = 'https://api.flickr.com/services/rest/?method=flickr.photos.search&api_key=' . $api_key . '&tags=' . $tags . '&format=json&nojsoncallback=1&per_page=' . $per_page . '&page=' . $this->page;
			$get_feeds = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
			$photos    = json_decode( $get_feeds );
			if ( isset( $photos->stat ) && 'fail' === $photos->stat ) {
				$message = $photos->message . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
			$get_php_error = Social_Stream_Main::ssd_get_last_error();
			if ( $get_php_error ) {
				$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
			if ( $this->page > 1 ) {
				$url           = 'https://api.flickr.com/services/rest/?method=flickr.photos.search&api_key=' . $api_key . '&tags=' . $tags . '&format=json&nojsoncallback=1&per_page=' . $per_page . '&page=' . $this->page;
				$get_feeds     = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
				$photos        = json_decode( $get_feeds );
				$get_php_error = Social_Stream_Main::ssd_get_last_error();
				if ( $get_php_error ) {
					$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
					return new WP_Error( 'ssd-feeds-errors', $message );
				}
			}
			if ( isset( $photos->photos->photo ) ) {
				if ( count( $photos->photos->photo ) < 1 ) {
					return 'Please enter "User ID"';
				}
			}
			if ( isset( $photos->photos->photo ) ) {
				$photos_data = $photos->photos->photo;
			} else {
				$photos_data = '';
			}
			if ( ! empty( $photos_data ) ) {
				foreach ( $photos_data as $photo ) {
					$photo_getinfo                  = $flickr_obj->photos_getInfo( $photo->id );
					$feeds['unique_id']             = $photo->id;
					$feeds['post_comment_id']       = $photo->id;
					$feeds['post_title']            = $photo->title;
					$feeds['post_description']      = ( isset( $photo->description->_content ) && '' !== $photo->description->_content ) ? $photo->description->_content : '';
					$feeds['post_date']             = gmdate( 'Y-m-d h:i:s', $photo_getinfo['photo']['dates']['posted'] );
					$feeds['post_link']             = 'https://www.flickr.com/photos/' . $photo->owner . '/' . $photo->id . '/in/dateposted/';
					$feeds['post_image']            = 'https://farm' . $photo->farm . '.static.flickr.com/' . $photo->server . '/' . $photo->id . '_' . $photo->secret . '_b.jpg';
					$feeds['url']                   = 'https://www.flickr.com/photos/' . $photo->owner . '/' . $photo->id . '/play/hd/' . $photo->secret;
					$feeds['post_user_name']        = $user_url['realname']['_content'];
					$feeds['post_user_screen_name'] = '';
					$feeds['post_user_link']        = $user_url['profileurl']['_content'];
					$feeds['post_favorite_count']   = '';
					$feeds['post_comment_count']    = $photo_getinfo['photo']['comments']['_content'];
					$feeds['post_plays_count']      = $photo_getinfo['photo']['views'];
					$feeds['post_likes_count']      = '';
					$feeds['post_dislikes_count']   = '';
					$feeds['type_in']               = 'video' === $photo_getinfo['photo']['media'] ? 'video' : 'image';
					$feeds['post_video']            = 'video' === $photo_getinfo['photo']['media'] ? 'https://www.flickr.com/photos/' . $photo->owner . '/' . $photo->id . '/in/dateposted/' : '';
					$this->ssd_feed_limit_count     = $this->ssd_feed_limit_count + 1;
					if ( $this->ssd_feed_limit_count <= $feed_limit ) {
						$this->flickr_feeds[] = $feeds;
					}
				}
			}
			if ( $this->ssd_feed_limit_count < $feed_limit ) {
				if ( $this->page <= $photos->photos->pages ) {
					$this->page = $this->page + 1;
					$this->ssd_get_flickr_stream_from_feed();
				}
			}
		} elseif ( 'user_photostream' === $feed_type_flickr ) {
			$photos = $flickr_obj->people_getPublicPhotos( $user_id, null, null, 10, 1 );
			if ( $this->page > 1 ) {
				$photos = $flickr_obj->people_getPublicPhotos( $user_id, null, null, 10, $this->page );
			}
			
			
			if ( count( $photos['photos']['photo'] ) < 1 ) {
				return 'Please enter "User ID"';
			}
			if ( isset( $photos['photos']['photo'] ) ) {
				$photos_data = $photos['photos']['photo'];
			} else {
				$photos_data = '';
			}
			if ( ! empty( $photos_data ) ) {
				foreach ( $photos_data as $photo ) {
					$photo_getinfo                  = $flickr_obj->photos_getInfo( $photo['id'] );
					$feeds['unique_id']             = $photo['id'];
					$feeds['post_comment_id']       = $photo['id'];
					$feeds['post_title']            = $photo['title'];
					$feeds['post_description']      = ( isset( $photo_getinfo['photo']['description']['_content'] ) && '' !== $photo_getinfo['photo']['description']['_content'] ) ? $photo_getinfo['photo']['description']['_content'] : '';
					$feeds['post_date']             = gmdate( 'Y-m-d h:i:s', $photo_getinfo['photo']['dates']['posted'] );
					$feeds['post_link']             = 'https://www.flickr.com/photos/' . $photo['owner'] . '/' . $photo['id'] . '/in/dateposted/';
					$feeds['post_image']            = $flickr_obj->buildPhotoURL( $photo, 'large' );
					$feeds['url']                   = 'https://www.flickr.com/photos/' . $photo['owner'] . '/' . $photo['id'] . '/play/hd/' . $photo['secret'];
					$feeds['post_user_name']        = $user_url['realname']['_content'];
					$feeds['post_user_screen_name'] = '';
					$feeds['post_user_link']        = $user_url['profileurl']['_content'];
					$feeds['post_favorite_count']   = '';
					$feeds['post_comment_count']    = $photo_getinfo['photo']['comments']['_content'];
					$feeds['post_plays_count']      = $photo_getinfo['photo']['views'];
					$feeds['post_likes_count']      = '';
					$feeds['post_dislikes_count']   = '';
					$feeds['type_in']               = 'video' === $photo_getinfo['photo']['media'] ? 'video' : 'image';
					$feeds['post_video']            = 'video' === $photo_getinfo['photo']['media'] ? 'https://www.flickr.com/photos/' . $photo['owner'] . '/' . $photo['id'] . '/in/dateposted/' : '';
					$this->ssd_feed_limit_count     = $this->ssd_feed_limit_count + 1;
					if ( $this->ssd_feed_limit_count <= $feed_limit ) {
						$this->flickr_feeds[] = $feeds;
					}
				}
			}
			if ( $this->ssd_feed_limit_count <= $feed_limit ) {
				if ( $this->page <= $photos['photos']['pages'] ) {
					$this->page = $this->page + 1;
					$this->ssd_get_flickr_stream_from_feed();
				}
			}
		}
		$flickr_feeds_data = $this->flickr_feeds;
		if ( ! empty( $flickr_feeds_data ) ) {
			foreach ( $flickr_feeds_data as $flickr_feed ) {
				$flickr_feed['feed_id']                   = $this->feed_id;
				$flickr_feed['reply_to_link']             = '';
				$flickr_feed['retweet_link']              = '';
				$flickr_feed['post_retweet_count']        = '';
				$flickr_feed['favourite_link']            = '';
				$flickr_feed['like_link']                 = '';
				$flickr_feed['play_link']                 = '';
				$flickr_feed['posttype']                  = '';
				$flickr_feed['carousel_media']            = '';
				$flickr_feed['message_2']                 = '';
				$flickr_feed['post_language']             = '';
				$flickr_feed['post_user_location']        = '';
				$flickr_feed['post_user_description']     = '';
				$flickr_feed['post_user_image']           = '';
				$flickr_feed['post_user_followers_count'] = '';
				$flickr_feed['post_user_friends_count']   = '';
				$flickr_feed['feed_type']                 = 'flickr';
				$this->post_feeds[]                       = $flickr_feed;
			}
		}
	}
}
