<?php
/**
 * RSS Social media class file get all social feed
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get RSS stream data
 *
 * @package    Social Stream Designer
 * @subpackage Social Stream Designer/admin/assets/feeds
 * @author     Solwin Infotech <support@solwininfotech.com>
 */
class SSDAdminrssFeeds {
	/**
	 * Table name
	 *
	 * @var string
	 */
	public $feed_posts_table = '';
	/**
	 * Feeds object
	 *
	 * @var string
	 */
	public $feeds_object = '';
	/**
	 * Feed Details
	 *
	 * @var string
	 */
	public $feed_detail = '';
	/**
	 * Feed ID
	 *
	 * @var int
	 */
	public $feed_id = '';
	/**
	 * Next URL
	 *
	 * @var string
	 */
	public $next_url = 1;
	/**
	 * Table name
	 *
	 * @var array
	 */
	public $post_feeds = array();
	/**
	 * Count Feed Limit
	 *
	 * @var int
	 */
	public $ssd_feed_limit_count = '0';
	/**
	 * Initial Setup
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function init() {
		global $wpdb;
		$this->feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		if ( isset( $_POST['feed_stream_nonce'] ) ) {
			if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
				if ( isset( $_REQUEST['action'] ) && 'edit' === $_REQUEST['action'] && isset( $_REQUEST['id'] ) && '' != $_REQUEST['id'] ) {
					$this->feed_id = sanitize_text_field( wp_unslash( $_REQUEST['id'] ) );
				}
			}
		}
		$feed_detail       = $this->ssd_get_feed_detail();
		$this->feed_detail = $feed_detail;
	}
	/**
	 * Get feed type from feed id.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_feed_detail() {
		global $wpdb;
		$feed_id      = $this->feed_id;
		$result_feeds = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
		if ( $result_feeds ) {
			$feeds_settings  = $result_feeds->feeds_settings;
			$feeds_settings  = maybe_unserialize( $feeds_settings );
			$this->feed_type = $feeds_settings['feed'];
			return $feeds_settings;
		} else {
			return '';
		}
	}
	/**
	 * Get feed Detail.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_rss_stream_from_feed() {
		$feed_detail  = $this->feed_detail;
		$channel_url  = $feed_detail['ssd_feed_type_rss_channel_url'];
		$avatar_url   = $feed_detail['ssd_feed_type_rss_avatar_url'];
		$channel_name = $feed_detail['ssd_feed_type_rss_channel_name'];
		$feed_limit   = $feed_detail['feed_limit'];
		if ( '' == $channel_url ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Channel ID' ) );
		}
		$rss_feed = fetch_feed( $channel_url );
		if ( isset( $rss_feed->errors ) ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' valid RSS feed URL' ) );
		}
		$item_metadata     = array();
		$item_all_metadata = array();
		if ( isset( $rss_feed->data['child'] ) && ! empty( $rss_feed->data['child'] ) ) {
			foreach ( $rss_feed->data['child'] as $items ) {
				foreach ( $items['rss'][0]['child'] as $data ) {
					foreach ( $data['channel'][0]['child'] as $results ) {
						if ( isset( $results['item'] ) ) {
							foreach ( $results['item'] as $child_item ) {
								foreach ( $child_item['child'] as $item ) {
									$created_date                       = strtotime( $item['pubDate'][0]['data'] );
									$feeds['feed_id']                   = $this->feed_id;
									$feeds['unique_id']                 = '';
									$feeds['post_comment_id']       	= '';
									$feeds['feed_type']                 = 'rss';
									$feeds['post_title']                = $item['title'][0]['data'];
									$feeds['post_description']          = $item['description'][0]['data'];
									$feeds['post_date']                 = gmdate( 'Y-m-d H:i:s', $created_date );
									$feeds['post_link']                 = $item['link'][0]['data'];
									$feeds['post_language']             = '';
									$feeds['post_user_name']            = $channel_name;
									$feeds['post_user_screen_name']     = $channel_name;
									$feeds['post_user_location']        = '';
									$feeds['post_user_description']     = '';
									$feeds['post_user_link']            = $item['link'][0]['data'];
									$feeds['post_user_image']           = $avatar_url;
									$feeds['post_user_followers_count'] = '';
									$feeds['post_user_friends_count']   = '';
									$feeds['post_retweet_count']        = '';
									$feeds['post_favorite_count']       = '';
									$feeds['post_comment_count']        = '';
									$feeds['post_plays_count']          = '0';
									$feeds['post_likes_count']          = '';
									$feeds['post_dislikes_count']       = '0';
									$feeds['reply_to_link']             = '';
									$feeds['retweet_link']              = '';
									$feeds['favourite_link']            = '';
									$feeds['like_link']                 = '';
									$feeds['play_link']                 = '';
									$feeds['type_in']                   = 'feed';
									$feeds['post_image']                = '';
									$feeds['post_video']                = '';
									$this->ssd_feed_limit_count         = $this->ssd_feed_limit_count + 1;
									if ( $this->ssd_feed_limit_count <= $feed_limit ) {
										$this->post_feeds[] = $feeds;
									}
								}
							}
						}
					}
				}
			}
		}
	}
}
