<?php
/**
 * Tumblr Social media class file get all social feed
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get Tumblr stream data
 *
 * @package    Social Stream Designer
 * @subpackage Social Stream Designer/admin/assets/feeds
 * @author     Solwin Infotech <support@solwininfotech.com>
 */
class SSDAdmintumblrFeeds {
	/**
	 * Table name
	 *
	 * @var string
	 */
	public $feed_posts_table = '';
	/**
	 * Feed Object
	 *
	 * @var string
	 */
	public $feeds_object = '';
	/**
	 * Feed Details
	 *
	 * @var string
	 */
	public $feed_detail = '';
	/**
	 * Feed Id
	 *
	 * @var int
	 */
	public $feed_id = '';
	/**
	 * Next page tokem
	 *
	 * @var int
	 */
	public $next_page_token = 0;
	/**
	 * Count loop
	 *
	 * @var int
	 */
	public $count_loop = 1;
	/**
	 * Tumblr Feeds
	 *
	 * @var array
	 */
	public $tumblr_feeds = array();
	/**
	 * Post Feeds
	 *
	 * @var array
	 */
	public $post_feeds = array();
	/**
	 * Count Feed Limit
	 *
	 * @var int
	 */
	public $ssd_feed_limit_count = '0';
	/**
	 * Initial Setup
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function init() {
		global $wpdb;
		$this->feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		if ( isset( $_POST['feed_stream_nonce'] ) ) {
			if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
				if ( isset( $_REQUEST['action'] ) && 'edit' === $_REQUEST['action'] && isset( $_REQUEST['id'] ) && '' != $_REQUEST['id'] ) {
					$this->feed_id = sanitize_text_field( wp_unslash( $_REQUEST['id'] ) );
				}
			}
		}
		$feed_detail       = $this->ssd_get_feed_detail();
		$this->feed_detail = $feed_detail;
	}
	/**
	 * Get feed type from feed id.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_feed_detail() {
		global $wpdb;
		$feed_id      = $this->feed_id;
		$feed_table   = $wpdb->prefix . 'ssd_feeds';
		$result_feeds = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
		if ( $result_feeds ) {
			$feeds_settings  = $result_feeds->feeds_settings;
			$feeds_settings  = maybe_unserialize( $feeds_settings );
			$this->feed_type = $feeds_settings['feed'];
			return $feeds_settings;
		} else {
			return '';
		}
	}
	/**
	 * Get all feeds.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_tumblr_stream_from_feed() {
		$feed_detail               = $this->feed_detail;
		$feed_type_tumblr_username = $feed_detail['feed_type_tumblr_username'];
		$tumblr_stream             = get_option( 'tumblr_stream' );
		$consumer_key              = $tumblr_stream['consumer_key'];
		$feed_limit                = $feed_detail['feed_limit'];
		if ( $feed_limit <= 100 ) {
			$limit = $feed_limit;
		} else {
			$limit = 20;
		}
		if ( '' == $consumer_key ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Authentication Missing. Please Check Authentication Setting', 'social-stream-designer' ) );
		}
		if ( '' == $feed_type_tumblr_username ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Username' ) );
		}
		$url             = 'https://api.tumblr.com/v2/blog/' . $feed_type_tumblr_username . '.tumblr.com/posts?api_key=' . $consumer_key . '&limit=' . $limit . '&offset=' . $this->next_page_token;
		$read_feed       = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
		$get_tumblr_feed = json_decode( $read_feed );
		if ( isset( $get_tumblr_feed->errors ) ) {
			$message = $get_tumblr_feed->errors[0]->title . ' Error !!! Please check your access token.';
			return new WP_Error( 'ssd-feeds-errors', $message );
		}
		$get_php_error = Social_Stream_Main::ssd_get_last_error();
		if ( $get_php_error ) {
			$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
			return new WP_Error( 'ssd-feeds-errors', $message );
		}
		$next_page             = $limit + $this->next_page_token;
		$this->next_page_token = $next_page;
		$total_post_no         = isset( $get_tumblr_feed->response->total_posts ) ? $get_tumblr_feed->response->total_posts : '';
		$feed_posts            = isset( $get_tumblr_feed->response->posts ) ? $get_tumblr_feed->response->posts : '';
		if ( ! empty( $feed_posts ) ) {
			foreach ( $get_tumblr_feed->response->posts as $feed ) {
				if ( isset( $feed->body ) ) {
					$post_description = $feed->body;
				} else {
					$post_description = $feed->summary;
				}
				if ( isset( $feed->caption ) ) {
					$caption = $feed->caption;
				} else {
					$caption = '';
				}
				$media_type = $feed->type;
				if ( 'photo' === $media_type ) {
					$feeds['type_in']    = 'image';
					$feeds['post_image'] = $feed->photos[0]->original_size->url;
					$feeds['post_video'] = '';
				} elseif ( 'video' === $media_type ) {
					$feeds['type_in']    = 'video';
					$feeds['post_image'] = '';
					$feeds['post_video'] = isset( $feed->video_url ) ? $feed->video_url : '';
				} else {
					$feeds['type_in']    = 'post';
					$feeds['post_image'] = '';
					$feeds['post_video'] = '';
				}
				$created_date                       = strtotime( $feed->date );
				$feeds['feed_id']                   = $this->feed_id;
				$feeds['unique_id']                 = $feed->id;
				$feeds['post_comment_id']       	= $feed->id;
				$feeds['feed_type']                 = 'tumblr';
				$feeds['post_title']                = $caption;
				$feeds['post_description']          = $post_description;
				$feeds['post_date']                 = gmdate( 'Y-m-d H:i:s', $created_date );
				$feeds['post_link']                 = $feed->post_url;
				$feeds['url']                       = $feed->post_url;
				$feeds['post_language']             = '';
				$feeds['post_user_name']            = $feed->blog_name;
				$feeds['post_user_screen_name']     = $feed->blog_name;
				$feeds['post_user_location']        = '';
				$feeds['post_user_description']     = '';
				$feeds['post_user_link']            = 'https://' . $feed->blog_name . '.tumblr.com/';
				$feeds['post_user_image']           = '';
				$feeds['post_user_followers_count'] = '';
				$feeds['post_user_friends_count']   = '';
				$feeds['post_retweet_count']        = '';
				$feeds['post_favorite_count']       = '';
				$feeds['post_comment_count']        = $feed->note_count;
				$feeds['post_plays_count']          = '0';
				$feeds['post_likes_count']          = $feed->can_like;
				$feeds['post_dislikes_count']       = '0';
				$feeds['reply_to_link']             = $feed->post_url;
				$feeds['retweet_link']              = '';
				$feeds['favourite_link']            = '';
				$feeds['like_link']                 = $feed->post_url;
				$feeds['play_link']                 = '';
				$this->ssd_feed_limit_count         = $this->ssd_feed_limit_count + 1;
				if ( $this->ssd_feed_limit_count <= $feed_limit ) {
					$this->post_feeds[] = $feeds;
				}
			}
		}
		if ( $this->ssd_feed_limit_count <= $feed_limit ) {
			if ( $this->next_page_token < $total_post_no ) {
				$this->ssd_get_tumblr_stream_from_feed();
			}
		}
	}
}
