<?php
/**
 * YouTube Social media class file get all social feed
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get YouTube stream data
 *
 * @package    Social Stream Designer
 * @subpackage Social Stream Designer/admin/assets/feeds
 * @author     Solwin Infotech <support@solwininfotech.com>
 */
class SSDAdminyoutubeFeeds {
	/**
	 * Table name
	 *
	 * @var string
	 */
	public $feed_posts_table = '';
	/**
	 * Feed Object
	 *
	 * @var string
	 */
	public $feeds_object = '';
	/**
	 * Feed Details
	 *
	 * @var string
	 */
	public $feed_detail = '';
	/**
	 * Feed ID
	 *
	 * @var int
	 */
	public $feed_id = '';
	/**
	 * Next Page Token
	 *
	 * @var string
	 */
	public $next_page_token = '';
	/**
	 * Youtube Feeds
	 *
	 * @var array
	 */
	public $youtube_feeds = array();
	/**
	 * Post Feeds
	 *
	 * @var array
	 */
	public $post_feeds = array();
	/**
	 * Count Feed Limit
	 *
	 * @var int
	 */
	public $ssd_feed_limit_count = '0';
	/**
	 * Initial Setup
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function init() {
		global $wpdb;
		$this->feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		if ( isset( $_POST['feed_stream_nonce'] ) ) {
			if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
				if ( isset( $_REQUEST['action'] ) && 'edit' === $_REQUEST['action'] && isset( $_REQUEST['id'] ) && '' != $_REQUEST['id'] ) {
					$this->feed_id = sanitize_text_field( wp_unslash( $_REQUEST['id'] ) );
				}
			}
		}
		$feed_detail       = $this->ssd_get_feed_detail();
		$this->feed_detail = $feed_detail;
	}
	/**
	 * Get feed type from feed id.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_feed_detail() {
		global $wpdb;
		$feed_id      = $this->feed_id;
		$result_feeds = $wpdb->get_row( $wpdb->prepare( "select * from  $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
		if ( $result_feeds ) {
			$feeds_settings  = $result_feeds->feeds_settings;
			$feeds_settings  = maybe_unserialize( $feeds_settings );
			$this->feed_type = $feeds_settings['feed'];
			return $feeds_settings;
		} else {
			return '';
		}
	}
	/**
	 * Get youtube stream.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_youtube_stream_from_feed() {
		$feed_detail       = $this->feed_detail;
		$feed_type_youtube = $feed_detail['feed_type_youtube'];
		$feed_limit        = $feed_detail['feed_limit'];
		$youtube_stream    = get_option( 'youtube_stream' );
		$youtube_api_key   = $youtube_stream['youtube_key'];
		if ( '' == $youtube_api_key ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Authentication Missing. Please Check Authentication Setting', 'social-stream-designer' ) );
		}
		if ( $feed_limit <= 50 ) {
			$max_results = $feed_limit;
		} else {
			$max_results = 50;
		}
		if ( 'search' === $feed_type_youtube ) {
			$youtube_search_query = $feed_detail['youtube_search_query'];
			if ( '' == $youtube_search_query ) {
				return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Keyword' ) );
			}
			$url         = 'https://www.googleapis.com/youtube/v3/search/?part=snippet&max_results=' . $max_results . '&q=' . $youtube_search_query . '&key=' . $youtube_api_key;
			$read_feed   = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
			$videos_data = json_decode( $read_feed );
			if ( isset( $videos_data->error ) ) {
				$message = $videos_data->error->errors[0]->message;
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
			$next_page_token = isset( $videos_data->nextPageToken ) ? $videos_data->nextPageToken : '';
			if ( '' != $this->next_page_token ) {
				$url         = 'https://www.googleapis.com/youtube/v3/search/?part=snippet&max_results=' . $max_results . '&q=' . $youtube_search_query . '&key=' . $youtube_api_key . '&pageToken=' . $this->next_page_token;
				$read_feed   = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
				$videos_data = json_decode( $read_feed );
				if ( isset( $videos_data->error ) ) {
					$message = $videos_data->error->errors[0]->message;
					return new WP_Error( 'ssd-feeds-errors', $message );
				}
				$next_page_token = isset( $videos_data->nextPageToken ) ? $videos_data->nextPageToken : '';
			}
			$get_php_error = Social_Stream_Main::ssd_get_last_error();
			if ( $get_php_error ) {
				$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
			$videos_data_items = $videos_data->items;
			if ( ! empty( $videos_data_items ) ) {
				foreach ( $videos_data_items as $video ) {
					if ( isset( $video->id->videoId ) ) {
						$video_id      = $video->id->videoId;
						$get_video_url = 'https://www.googleapis.com/youtube/v3/videos?part=id%2C+snippet%2C+statistics&id=' . $video_id . '&key=' . $youtube_api_key;
						$read_feed     = Social_Stream_Main::ssd_get_data_from_remote_url( $get_video_url );
						$video_data    = json_decode( $read_feed );
						if ( isset( $video_data->error ) ) {
							$message = $video_data->error->errors[0]->message;
							return new WP_Error( 'ssd-feeds-errors', $message );
						}
						$video_list = $video_data->items;
						if ( ! empty( $video_list ) ) {
							foreach ( $video_list as $feed ) {
								$feeds['unique_id']             = $feed->id;
								$feeds['post_comment_id']       = $video_id;
								$feeds['post_title']            = $feed->snippet->title;
								$feeds['post_description']      = $feed->snippet->description;
								$feeds['post_date']             = $feed->snippet->publishedAt;
								$feeds['post_link']             = 'https://www.youtube.com/watch?v=' . $feed->id;
								$feeds['post_image']            = $feed->snippet->thumbnails->high->url;
								$feeds['url']                   = 'https://www.youtube.com/embed/' . $feed->id . '?rel=0&amp;showinfo=0';
								$feeds['post_user_name']        = $feed->snippet->channelTitle;
								$feeds['post_user_screen_name'] = $feed->snippet->channelTitle;
								$feeds['post_user_link']        = 'https://www.youtube.com/channel/' . $feed->snippet->channelId;
								$feeds['post_favorite_count']   = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->favoriteCount );
								$feeds['post_comment_count']    = isset( $feed->statistics->commentCount ) ? Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->commentCount ) : '';
								$feeds['post_plays_count']      = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->viewCount );
								$feeds['post_likes_count']      = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->likeCount );
								$feeds['post_dislikes_count']   = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->dislikeCount );
								$feeds['type_in']               = 'video';
								$feeds['post_video']            = 'https://www.youtube.com/embed/' . $feed->id;
								$this->ssd_feed_limit_count     = $this->ssd_feed_limit_count + 1;
								if ( $this->ssd_feed_limit_count <= $feed_limit ) {
									$this->youtube_feeds[] = $feeds;
								}
							}
						}
					}
				}
			}
			if ( $this->ssd_feed_limit_count <= $feed_limit ) {
				if ( isset( $next_page_token ) && '' !== $next_page_token ) {
					$this->next_page_token = $next_page_token;
					$this->ssd_get_youtube_stream_from_feed();
				}
			}
		} elseif ( 'channel' === $feed_type_youtube ) {
			$channel_id = $feed_detail['youtube_channel_id'];
			if ( '' === $channel_id ) {
				return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Channel' ) );
			}
			$url         = 'https://www.googleapis.com/youtube/v3/search?part=snippet&type=video&order=date&max_results=' . $max_results . '&channelId=' . $channel_id . '&key=' . $youtube_api_key;
			$read_feed   = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
			$videos_data = json_decode( $read_feed );
			if ( isset( $videos_data->error ) ) {
				$message = $videos_data->error->errors[0]->message;
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
			$next_page_token = isset( $videos_data->nextPageToken ) ? $videos_data->nextPageToken : '';
			if ( '' !== $this->next_page_token ) {
				$url         = 'https://www.googleapis.com/youtube/v3/search/?part=snippet&max_results=' . $max_results . '&channelId=' . $channel_id . '&key=' . $youtube_api_key . '&pageToken=' . $this->next_page_token;
				$read_feed   = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
				$videos_data = json_decode( $read_feed );
				if ( isset( $videos_data->error ) ) {
					$message = $videos_data->error->errors[0]->message;
					return new WP_Error( 'ssd-feeds-errors', $message );
				}
				$next_page_token = isset( $videos_data->nextPageToken ) ? $videos_data->nextPageToken : '';
			}
			$get_php_error = Social_Stream_Main::ssd_get_last_error();
			if ( $get_php_error ) {
				$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
			$videos_data_items = $videos_data->items;
			if ( ! empty( $videos_data_items ) ) {
				foreach ( $videos_data_items as $video ) {
					$video_id = '';
					if ( isset( $video->id ) ) {
						$video_id = $video->id->videoId;
					}
					$get_video_url = 'https://www.googleapis.com/youtube/v3/videos?part=id%2C+snippet%2C+statistics&id=' . $video_id . '&key=' . $youtube_api_key;
					$read_feed     = Social_Stream_Main::ssd_get_data_from_remote_url( $get_video_url );
					$video_data    = json_decode( $read_feed );
					if ( isset( $video_data->error ) ) {
						$message = $video_data->error->errors[0]->message;
						return new WP_Error( 'ssd-feeds-errors', $message );
					}
					$video_list = $video_data->items;
					if ( ! empty( $video_list ) ) {
						foreach ( $video_list as $feed ) {
							$feeds['unique_id']             = $feed->id;
							$feeds['post_comment_id']       = $video_id;
							$feeds['post_title']            = $feed->snippet->title;
							$feeds['post_description']      = $feed->snippet->description;
							$feeds['post_date']             = $feed->snippet->publishedAt;
							$feeds['post_link']             = 'https://www.youtube.com/watch?v=' . $feed->id;
							$feeds['post_image']            = $feed->snippet->thumbnails->high->url;
							$feeds['url']                   = 'https://www.youtube.com/embed/' . $feed->id . '?rel=0&amp;showinfo=0';
							$feeds['post_user_name']        = $feed->snippet->channelTitle;
							$feeds['post_user_screen_name'] = $feed->snippet->channelTitle;
							$feeds['post_user_link']        = 'https://www.youtube.com/channel/' . $feed->snippet->channelId;
							$feeds['post_favorite_count']   = isset( $feed->statistics->favoriteCount ) ? Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->favoriteCount ) : 0;
							$feeds['post_comment_count']    = isset( $feed->statistics->commentCount ) ? Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->commentCount ) : 0;
							$feeds['post_plays_count']      = isset( $feed->statistics->viewCount ) ? Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->viewCount ) : 0;
							$feeds['post_likes_count']      = isset( $feed->statistics->likeCount ) ? Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->likeCount ) : 0;
							$feeds['post_dislikes_count']   = isset( $feed->statistics->dislikeCount ) ? Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->dislikeCount ) : 0;
							$feeds['type_in']               = 'video';
							$feeds['post_video']            = 'https://www.youtube.com/embed/' . $feed->id;
							$this->ssd_feed_limit_count     = $this->ssd_feed_limit_count + 1;
							if ( $this->ssd_feed_limit_count <= $feed_limit ) {
								$this->youtube_feeds[] = $feeds;
							}
						}
					}
				}
			}
			if ( $this->ssd_feed_limit_count <= $feed_limit ) {
				if ( isset( $next_page_token ) && '' !== $next_page_token ) {
					$this->next_page_token = $next_page_token;
					$this->ssd_get_youtube_stream_from_feed();
				}
			}
		} elseif ( 'playlists' === $feed_type_youtube ) {
			$playlist_id = $feed_detail['youtube_playlist_id'];
			if ( '' === $playlist_id ) {
				return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Playlist ID' ) );
			}
			$url       = 'https://www.googleapis.com/youtube/v3/playlistItems?part=snippet&max_results=' . $max_results . '&playlistId=' . $playlist_id . '&key=' . $youtube_api_key;
			$read_feed = Social_Stream_Main::ssd_get_data_from_remote_url( $url );

			$videos_data = json_decode( $read_feed );
			if ( isset( $videos_data->error ) ) {
				$message = $videos_data->error->errors[0]->message;
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
			$next_page_token = isset( $videos_data->nextPageToken ) ? $videos_data->nextPageToken : '';
			if ( '' !== $this->next_page_token ) {
				$url       = 'https://www.googleapis.com/youtube/v3/search/?part=snippet&max_results=' . $max_results . '&key=' . $youtube_api_key . '&pageToken=' . $this->next_page_token;
				$read_feed = Social_Stream_Main::ssd_get_data_from_remote_url( $url );

				$videos_data = json_decode( $read_feed );
				if ( isset( $videos_data->error ) ) {
					$message = $videos_data->error->errors[0]->message;
					return new WP_Error( 'ssd-feeds-errors', $message );
				}
				$next_page_token = isset( $videos_data->nextPageToken ) ? $videos_data->nextPageToken : '';
			}
			$get_php_error = Social_Stream_Main::ssd_get_last_error();
			if ( $get_php_error ) {
				$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
			$videos_data_items = $videos_data->items;
			if ( ! empty( $videos_data_items ) ) {
				foreach ( $videos_data->items as $video ) {
					$video_id      = $video->snippet->resourceId->videoId;
					$get_video_url = 'https://www.googleapis.com/youtube/v3/videos?part=id%2C+snippet%2C+statistics&id=' . $video_id . '&key=' . $youtube_api_key;
					$read_feed     = Social_Stream_Main::ssd_get_data_from_remote_url( $get_video_url );
					$video_data    = json_decode( $read_feed );
					$get_php_error = Social_Stream_Main::ssd_get_last_error();
					if ( $get_php_error ) {
						$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
						return new WP_Error( 'ssd-feeds-errors', $message );
					}
					if ( isset( $video_data->error ) ) {
						$message = $video_data->error->errors[0]->message;
						return new WP_Error( 'ssd-feeds-errors', $message );
					}
					$video_list = $video_data->items;
					if ( ! empty( $video_list ) ) {
						foreach ( $video_list as $feed ) {
							$feeds['unique_id']             = $feed->id;
							$feeds['post_comment_id']       = $video_id;
							$feeds['post_title']            = $feed->snippet->title;
							$feeds['post_description']      = $feed->snippet->description;
							$feeds['post_date']             = $feed->snippet->publishedAt;
							$feeds['post_link']             = 'https://www.youtube.com/watch?v=' . $feed->id;
							$feeds['post_image']            = $feed->snippet->thumbnails->high->url;
							$feeds['url']                   = 'https://www.youtube.com/embed/' . $feed->id . '?rel=0&amp;showinfo=0';
							$feeds['post_user_name']        = $feed->snippet->channelTitle;
							$feeds['post_user_screen_name'] = $feed->snippet->channelTitle;
							$feeds['post_user_link']        = 'https://www.youtube.com/channel/' . $feed->snippet->channelId;
							$feeds['post_favorite_count']   = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->favoriteCount );
							$feeds['post_comment_count']    = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->commentCount );
							$feeds['post_plays_count']      = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->viewCount );
							$feeds['post_likes_count']      = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->likeCount );
							$feeds['post_dislikes_count']   = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->dislikeCount );
							$feeds['type_in']               = 'video';
							$feeds['post_video']            = 'https://www.youtube.com/embed/' . $feed->id;
							$this->ssd_feed_limit_count     = $this->ssd_feed_limit_count + 1;
							if ( $this->ssd_feed_limit_count <= $feed_limit ) {
								$this->youtube_feeds[] = $feeds;
							}
						}
					}
				}
			}
			if ( $this->ssd_feed_limit_count <= $feed_limit ) {
				if ( isset( $next_page_token ) && '' !== $next_page_token ) {
					$this->next_page_token = $next_page_token;
					$this->ssd_get_youtube_stream_from_feed();
				}
			}
		} elseif ( 'user_feed' === $feed_type_youtube ) {
			$youtube_username = $feed_detail['youtube_username'];
			if ( '' === $youtube_username ) {
				return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Username' ) );
			}
			$url        = 'https://www.googleapis.com/youtube/v3/channels?part=snippet%2CcontentDetails&forUsername=' . $youtube_username . '&key=' . $youtube_api_key;
			$read_feed  = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
			$video_data = json_decode( $read_feed );
			if ( isset( $video_data->error ) ) {
				$message = $video_data->error->errors[0]->message;
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
			if ( isset( $video_data->items ) ) {
				$video_list = $video_data->items;
			} else {
				$video_list = '';
			}
			if ( ! empty( $video_list ) ) {
				foreach ( $video_list as $item ) {
					$url        = 'https://www.googleapis.com/youtube/v3/playlistItems?part=id%2Csnippet&playlistId=' . $item->contentDetails->relatedPlaylists->uploads . '&max_results=' . $max_results . '&key=' . $youtube_api_key;
					$read_feed  = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
					$video_data = json_decode( $read_feed );
					if ( isset( $video_data->error ) ) {
						$message = $video_data->error->errors[0]->message;
						return new WP_Error( 'ssd-feeds-errors', $message );
					}
					$next_page_token = isset( $video_data->nextPageToken ) ? $video_data->nextPageToken : '';
					if ( '' !== $this->next_page_token ) {
						$url       = 'https://www.googleapis.com/youtube/v3/playlistItems?part=id%2Csnippet&playlistId=' . $item->contentDetails->relatedPlaylists->uploads . '&max_results=' . $max_results . '&key=' . $youtube_api_key . '&pageToken=' . $this->next_page_token;
						$read_feed = Social_Stream_Main::ssd_get_data_from_remote_url( $url );

						$video_data = json_decode( $read_feed );
						if ( isset( $video_data->error ) ) {
							$message = $video_data->error->errors[0]->message;
							return new WP_Error( 'ssd-feeds-errors', $message );
						}
					}
					$video_list = $video_data->items;
					if ( ! empty( $video_list ) ) {
						foreach ( $video_list as $video ) {
							$video_id      = $video->snippet->resourceId->videoId;
							$get_video_url = 'https://www.googleapis.com/youtube/v3/videos?part=id%2C+snippet%2C+statistics&id=' . $video_id . '&key=' . $youtube_api_key;
							$read_feed     = Social_Stream_Main::ssd_get_data_from_remote_url( $get_video_url );

							$video_data    = json_decode( $read_feed );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();
							if ( $get_php_error ) {
								$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
								return new WP_Error( 'ssd-feeds-errors', $message );
							}

							if ( isset( $video_data->error ) ) {
								$message = $video_data->error->errors[0]->message;
								return new WP_Error( 'ssd-feeds-errors', $message );
							}
							$video_list = $video_data->items;
							if ( ! empty( $video_list ) ) {
								foreach ( $video_list as $feed ) {
									$feeds['unique_id']             = $feed->id;
									$feeds['post_comment_id']       = $video_id;
									$feeds['post_title']            = $feed->snippet->title;
									$feeds['post_description']      = $feed->snippet->description;
									$feeds['post_date']             = $feed->snippet->publishedAt;
									$feeds['post_link']             = 'https://www.youtube.com/watch?v=' . $feed->id;
									$feeds['post_image']            = $feed->snippet->thumbnails->high->url;
									$feeds['url']                   = 'https://www.youtube.com/embed/' . $feed->id . '?rel=0&amp;showinfo=0';
									$feeds['post_user_name']        = $feed->snippet->channelTitle;
									$feeds['post_user_screen_name'] = $feed->snippet->channelTitle;
									$feeds['post_user_link']        = 'https://www.youtube.com/channel/' . $feed->snippet->channelId;
									$feeds['post_favorite_count']   = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->favoriteCount );
									$feeds['post_comment_count']    = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->commentCount );
									$feeds['post_plays_count']      = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->viewCount );
									$feeds['post_likes_count']      = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->likeCount );
									$feeds['post_dislikes_count']   = Social_Stream_Main::ssd_formatwithsuffix( $feed->statistics->dislikeCount );
									$feeds['type_in']               = 'video';
									$feeds['post_video']            = 'https://www.youtube.com/embed/' . $feed->id;
									$this->ssd_feed_limit_count     = $this->ssd_feed_limit_count + 1;
									if ( $this->ssd_feed_limit_count <= $feed_limit ) {
										$this->youtube_feeds[] = $feeds;
									}
								}
							}
						}
					}
					if ( $this->ssd_feed_limit_count <= $feed_limit ) {
						if ( isset( $next_page_token ) && '' !== $next_page_token ) {
							$this->next_page_token = $next_page_token;
							$this->ssd_get_youtube_stream_from_feed();
						}
					}
				}
			}
		}
		$youtube_feeds_new  = array();
		$youtube_feeds_data = $this->youtube_feeds;
		if ( ! empty( $youtube_feeds_data ) ) {
			foreach ( $youtube_feeds_data as $youtube_feed ) {
				$youtube_feed['feed_id']                   = $this->feed_id;
				$youtube_feed['reply_to_link']             = '';
				$youtube_feed['retweet_link']              = '';
				$youtube_feed['post_retweet_count']        = '';
				$youtube_feed['favourite_link']            = '';
				$youtube_feed['like_link']                 = '';
				$youtube_feed['play_link']                 = '';
				$youtube_feed['posttype']                  = '';
				$youtube_feed['carousel_media']            = '';
				$youtube_feed['message_2']                 = '';
				$youtube_feed['post_language']             = '';
				$youtube_feed['post_user_location']        = '';
				$youtube_feed['post_user_description']     = '';
				$youtube_feed['post_user_image']           = '';
				$youtube_feed['post_user_followers_count'] = '';
				$youtube_feed['post_user_friends_count']   = '';
				$youtube_feed['feed_type']                 = 'youtube';
				$youtube_feeds_new[]                       = $youtube_feed;
			}
		}
		$this->post_feeds = $youtube_feeds_new;
	}
}
