<?php
/**
 * Class file for all actions of stream
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Class for all actions of stream.
 */
class SocialStream {
	/**
	 * Class for all actions of stream.
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'ssd_add_menu' ) );
		add_action( 'admin_init', array( $this, 'ssd_include_autoupdate' ), 10 );
		add_action( 'admin_init', array( $this, 'ssd_save_admin_template' ), 10 );
		add_action( 'admin_init', array( $this, 'ssd_delete_admin_template' ), 11 );
		add_action( 'admin_init', array( $this, 'ssd_duplicate_admin_template' ), 12 );
		add_action( 'init', array( $this, 'ssd_layout_export' ), 13 );
		add_action( 'admin_notices', array( $this, 'general_admin_notice' ) );
		add_action( 'admin_init', array( $this, 'ssd_layout_demo_import' ), 18 );
		add_action( 'admin_enqueue_scripts', array( $this, 'ssd_admin_script_style' ), 10 );
		add_action( 'wp_enqueue_scripts', array( $this, 'ssd_front_end_script_style' ), 10 );
		add_filter( 'set-screen-option', array( $this, 'ssd_set_option' ), 10, 3 );
		add_action( 'plugins_loaded', array( $this, 'ssd_load_language_files' ), 10 );
		add_action( 'admin_head', array( $this, 'ssd_read_all_feed_for_refresh' ), 10 );
		add_action( 'wp_head', array( $this, 'ssd_read_all_feed_for_refresh' ), 10 );
		add_action( 'wp_ajax_nopriv_ssd_action_check_for_refresh_feed', array( $this, 'ssd_refresh_feeds' ), 10 );
		add_action( 'wp_ajax_ssd_action_check_for_refresh_feed', array( $this, 'ssd_refresh_feeds' ), 10 );

		add_action( 'wp_ajax_nopriv_ssd_facebook_album', array( $this, 'ssd_facebook_album' ), 10 );
		add_action( 'wp_ajax_ssd_facebook_album', array( $this, 'ssd_facebook_album' ), 10 );

		add_action( 'wp_ajax_nopriv_ssd_display_comments_popup', array( $this, 'ssd_display_comments_popup' ), 10 );
		add_action( 'wp_ajax_ssd_display_comments_popup', array( $this, 'ssd_display_comments_popup' ), 10 );
		
		add_action( 'wp_ajax_ssd_feed_bio_details', array( $this, 'ssd_feed_bio_details' ) );
		add_action( 'wp_ajax_nopriv_ssd_feed_bio_details', array( $this, 'ssd_feed_bio_details' ) );
		add_action( 'wp_ajax_ssd_update_feed_status', array( $this, 'ssd_update_status_feeds' ), 10 );
		add_action( 'wp_ajax_ssd_update_feed_live_status', array( $this, 'ssd_update_live_status_feeds' ), 10 );
		add_action( 'wp_ajax_ssd_set_order', array( $this, 'ssd_set_order' ), 10 );
		add_action( 'wp_ajax_ssd_corner_icon', array( $this, 'ssd_corner_icon' ), 10 );
		add_action( 'wp_ajax_ssd_update_sticky_on', array( $this, 'ssd_update_sticky_on' ), 10 );
		add_action( 'wp_ajax_ssd_reset_layout_settings', array( &$this, 'ssd_reset_layout_settings' ), 10 );
		add_action( 'wp_ajax_ssd_design_preview_request', array( $this, 'ssd_design_preview_request' ), 10 );
		add_shortcode( 'social_stream_feeds', array( $this, 'ssd_feeds_shortcode' ) );
		add_action( 'admin_init', array( $this, 'ssd_replace_wordpress_feed' ), 12 );
		add_action( 'wp_ajax_ssd_search_data', array( $this, 'ssd_search_data' ) );
		add_action( 'wp_ajax_nopriv_ssd_search_data', array( $this, 'ssd_search_data' ) );
		add_action( 'vc_before_init', array( &$this, 'ssd_add_vc_support' ) );
		add_action( 'init', array($this, 'ssd_init_session') );
	}

	/** 
	 * Start session on init hook.
	*/
	public function ssd_init_session() {
		if ( ! session_id() ) {
			session_start(['read_and_close' => true]);
		}
	}
	
	/**
	 * Argument for Kses.
	 *
	 * @since    1.0.0
	 * @return  array
	 */
	public static function args_kses() {
		$args_kses = array(
			'div'    => array(
				'class'  => true,
				'id'     => true,
				'style'  => true,
				'script' => true,
				'adid'   => true,
				'bdid'   => true,
				'btype'  => true,
				'adview' => true,
				'bid'    => true,
			),
			'script' => array(
				'type'    => true,
				'charset' => true,
			),
			'style'  => array(
				'type' => true,
			),
			'iframe' => array(
				'class'        => true,
				'src'          => true,
				'style'        => true,
				'marginwidth'  => true,
				'marginheight' => true,
				'scrolling'    => true,
				'frameborder'  => true,
			),
			'img'    => array(
				'class' => true,
				'src'   => true,
			),
			'a'      => array(
				'href'   => true,
				'adid'   => true,
				'bdid'   => true,
				'btype'  => true,
				'adview' => true,
				'bid'    => true,
				'class'  => true,
			),
			'ul'     => array(
				'class' => true,
				'id'    => true,
				'style' => true,
			),
			'li'     => array(
				'class' => true,
				'id'    => true,
				'style' => true,
			),
			'p'      => array(
				'class' => true,
				'id'    => true,
				'style' => true,
			),
			'i'      => array(
				'class' => true,
				'style' => true,
			),
			'h1'     => array(
				'class' => true,
				'style' => true,
			),
			'h4'     => array(
				'class' => true,
				'style' => true,
			),
			'span'   => array(
				'class' => true,
				'style' => true,
			),
		);
		return $args_kses;
	}
	/**
	 * Display layout
	 *
	 * @param string $atts shortcode id.
	 * @return string
	 */
	public function ssd_feeds_shortcode( $atts ) {
		$layout_object = new SSDLayoutsActions();
		$layout_object->init();
		$shortcode_id           = $atts['id'];
		$layout_object->id      = $shortcode_id;
		$layout_settings        = $layout_object->ssd_get_layout_detail();
		$shortcode_name         = ( isset( $layout_settings->shortcode_name ) && '' !== $layout_settings->shortcode_name ) ? $layout_settings->shortcode_name : '';
		$social_stream_settings = unserialize( $layout_settings->social_stream_settings );
		if ( isset( $_POST['nonce'] ) ) {
			$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );
			if ( ! wp_verify_nonce( $nonce, 'ajax-nonce' ) ) {
				wp_send_json_error( array( 'ssd_shortcodes' => 'Nonce error' ) );
				die();
			}
		}
		if ( ! $layout_settings ) {
			return '<b style="color:#ff0000">' . esc_html__( 'Error', 'social-stream-designer' ) . ' : </b>' . esc_html__( 'Social Stream Feeds shortcode not found. Please cross check your Social Stream Feeds ID.', 'social-stream-designer' );
		}
		// Get feed ids to get feed posts.
		$feed_ids = $social_stream_settings['feed_ids'];
		$feed_ids = array_values( $feed_ids );
		$feed_ids = implode( ',', $feed_ids );
		// Get pagination options.
		$ssd_display_private_stream = isset( $social_stream_settings['ssd_display_private_stream'] ) ? $social_stream_settings['ssd_display_private_stream'] : 0;
		$ssd_hide_desktop_stream    = isset( $social_stream_settings['ssd_hide_desktop_stream'] ) ? $social_stream_settings['ssd_hide_desktop_stream'] : 0;
		$ssd_hide_mobile_stream     = isset( $social_stream_settings['ssd_hide_mobile_stream'] ) ? $social_stream_settings['ssd_hide_mobile_stream'] : 0;
		$no_of_posts_per_page       = ( isset( $social_stream_settings['ssd_no_of_posts_per_page'] ) && $social_stream_settings['ssd_no_of_posts_per_page'] > 1 ) ? $social_stream_settings['ssd_no_of_posts_per_page'] : 6;
		$total_number_of_posts      = ( isset( $social_stream_settings['ssd_no_of_posts'] ) && $social_stream_settings['ssd_no_of_posts'] > 1 ) ? $social_stream_settings['ssd_no_of_posts'] : '-1';
		$cur_page                   = ( isset( $_REQUEST['cur_page'] ) && sanitize_text_field( wp_unslash( $_REQUEST['cur_page'] ) ) > 0 ) ? sanitize_text_field( wp_unslash( $_REQUEST['cur_page'] ) ) : 1;
		$search_val                   = ( isset( $_REQUEST['search_val'] ) && !empty( $_REQUEST['search_val'] ) ) ? sanitize_text_field( wp_unslash( $_REQUEST['search_val'] ) ) : '';
		$ssd_pagination_type        = 'no_pagination';
		$ssd_design_layout          = isset( $social_stream_settings['ssd_design_layout'] ) ? $social_stream_settings['ssd_design_layout'] : '';
		$layout                     = isset( $social_stream_settings['ssd_layout'] ) ? $social_stream_settings['ssd_layout'] : 'listing';
		$order                      = isset( $social_stream_settings['ssd_display_order'] ) ? $social_stream_settings['ssd_display_order'] : 0;
		$order_by                   = isset( $social_stream_settings['ssd_order_by'] ) ? $social_stream_settings['ssd_order_by'] : 'date';
		$ssd_display_filter         = isset( $social_stream_settings['ssd_display_filter'] ) ? $social_stream_settings['ssd_display_filter'] : 0;
		$ssd_grid_style             = isset( $social_stream_settings['ssd_grid_style'] ) ? $social_stream_settings['ssd_grid_style'] : 'masonry';
		if ( 'layout-4' !== $ssd_design_layout ) {
			$ssd_grid_style = 'masonry';
		}
		if ( 'listing' !== $layout ) {
			$ssd_grid_style = '';
		}
		$ssd_stream_title                = isset( $social_stream_settings['ssd_stream_title'] ) ? $social_stream_settings['ssd_stream_title'] : '';
		$ssd_stream_subtitle             = isset( $social_stream_settings['ssd_stream_subtitle'] ) ? $social_stream_settings['ssd_stream_subtitle'] : '';
		$ssd_heading_alignment           = isset( $social_stream_settings['ssd_heading_alignment'] ) ? $social_stream_settings['ssd_heading_alignment'] : 'center';
		$ssd_display_feed_without_media0 = (int) isset( $social_stream_settings['ssd_display_feed_without_media'] ) ? $social_stream_settings['ssd_display_feed_without_media'] : 1;
		$ssd_justified_grid_height       = isset( $social_stream_settings['ssd_justified_grid_height'] ) ? $social_stream_settings['ssd_justified_grid_height'] : '200';
		$ssd_column_type                 = isset( $social_stream_settings['ssd_column_type'] ) ? $social_stream_settings['ssd_column_type'] : 3;
		$ssd_column_type_laptop          = isset( $social_stream_settings['ssd_column_type_laptop'] ) ? $social_stream_settings['ssd_column_type_laptop'] : 3;
		$ssd_column_type_rotated_tablet  = isset( $social_stream_settings['ssd_column_type_rotated_tablet'] ) ? $social_stream_settings['ssd_column_type_rotated_tablet'] : 3;
		$ssd_column_type_tablet          = isset( $social_stream_settings['ssd_column_type_tablet'] ) ? $social_stream_settings['ssd_column_type_tablet'] : 2;
		$ssd_column_type_rotated_mobile  = isset( $social_stream_settings['ssd_column_type_rotated_mobile'] ) ? $social_stream_settings['ssd_column_type_rotated_mobile'] : 1;
		$ssd_column_type_mobile          = isset( $social_stream_settings['ssd_column_type_mobile'] ) ? $social_stream_settings['ssd_column_type_mobile'] : 1;
		$ssd_column_type_vertical        = isset( $social_stream_settings['ssd_column_type_vertical'] ) ? $social_stream_settings['ssd_column_type_vertical'] : 3;
		$ssd_display_slider_nav          = isset( $social_stream_settings['ssd_display_slider_nav'] ) ? $social_stream_settings['ssd_display_slider_nav'] : 1;
		$ssd_display_autoplay            = isset( $social_stream_settings['ssd_display_autoplay'] ) ? $social_stream_settings['ssd_display_autoplay'] : 0;
		$ssd_display_slider_playpause    = isset( $social_stream_settings['ssd_display_slider_playpause'] ) ? $social_stream_settings['ssd_display_slider_playpause'] : 1;
		$ssd_slider_interval             = isset( $social_stream_settings['ssd_slider_interval'] ) ? $social_stream_settings['ssd_slider_interval'] : 3000;
		$ssd_slider_speed                = isset( $social_stream_settings['ssd_slider_speed'] ) ? $social_stream_settings['ssd_slider_speed'] : 3000;
		$ssd_display_media_slider_arrows = isset( $social_stream_settings['ssd_display_media_slider_arrows'] ) ? $social_stream_settings['ssd_display_media_slider_arrows'] : 0;
		$ssd_display_media_autoplay      = isset( $social_stream_settings['ssd_display_media_autoplay'] ) ? $social_stream_settings['ssd_display_media_autoplay'] : 0;
		$ssd_slider_media_interval       = isset( $social_stream_settings['ssd_slider_media_interval'] ) ? $social_stream_settings['ssd_slider_media_interval'] : 3000;
		$ssd_slider_media_speed          = isset( $social_stream_settings['ssd_slider_media_speed'] ) ? $social_stream_settings['ssd_slider_media_speed'] : 3000;
		$ssd_slider_direction            = isset( $social_stream_settings['ssd_slider_direction'] ) ? $social_stream_settings['ssd_slider_direction'] : 'horizontal';
		$ssd_slider_width                = isset( $social_stream_settings['ssd_slider_width'] ) ? $social_stream_settings['ssd_slider_width'] : '800';
		$ssd_row_type                    = isset( $social_stream_settings['ssd_row_type'] ) ? $social_stream_settings['ssd_row_type'] : 1;
		$ssd_display_search              = isset( $social_stream_settings['ssd_display_search'] ) ? $social_stream_settings['ssd_display_search'] : 0;
		$ssd_display_feed_without_media  = (int) $ssd_display_feed_without_media0;
		$ssd_feed_types	= array('image','video','carousel');

		$ssd_feed_types                    = ( isset( $social_stream_settings['feed_types'] ) && '' !== $social_stream_settings['feed_types'] ) ? $social_stream_settings['feed_types'] : $ssd_feed_types;
		// $ssd_feed_types = implode( ',', $ssd_feed_types );
		$feed_object                     = new SSDFeedsActions();
		$feed_object->init();
		$feed_live_status = array();
		$all_feeds        = $feed_object->ssd_get_all_feeds();
		if ( is_array( $all_feeds ) && ! empty( $all_feeds ) ) {
			foreach ( $all_feeds as $single_feed ) {
				if ( in_array( $single_feed->id, $social_stream_settings['feed_ids'], true ) ) {
					$feeds_settings       = maybe_unserialize( $single_feed->feeds_settings );
					$all_feed_status_live = isset( $feeds_settings['feed_status_live'] ) ? $feeds_settings['feed_status_live'] : 'Live';
					if ( 'Live' === $all_feed_status_live ) {
						$feed_live_status[ $single_feed->id ] = isset( $feeds_settings['feed_status_live'] ) ? $feeds_settings['feed_status_live'] : 'Live';
					}
				}
			}
		}
		$total_feed_count = '';

		if ( ( 'listing' === $layout || 'timeline' === $layout ) ) {
			$ssd_pagination_type = isset( $social_stream_settings['ssd_pagination_type'] ) ? $social_stream_settings['ssd_pagination_type'] : 'no_pagination';
		}

		// Set pagination options.
		$feeds_object = new SSDFrontFeeds();
		$feeds_object->init();
		$feeds_object->feed_id                        = $feed_ids;
		$feeds_object->ssd_display_order              = $order;
		$feeds_object->ssd_order_by                   = $order_by;
		$feeds_object->ssd_search                     = $search_val;
		$feeds_object->ssd_feed_types                     = $ssd_feed_types;
		
		$feeds_object->ssd_display_feed_without_media = $ssd_display_feed_without_media;

		if ( 1 == $ssd_display_feed_without_media ) {
			$ssd_total_stream = $feeds_object->ssd_total_stream();
		} else {
			$ssd_total_stream = $feeds_object->ssd_total_stream_without_image();
		}
		if ( $ssd_total_stream > $total_number_of_posts ) {
			$total_feeds = $total_number_of_posts;
		} else {
			$total_feeds = $ssd_total_stream;
		}
		if ( -1 == $total_number_of_posts ) {
			$total_feeds = $ssd_total_stream;
		} else {
			$feeds_object->max_number_of_posts = $total_number_of_posts;
		}

		if ( 'no_pagination' === $ssd_pagination_type ) {
			$feeds_object->posts_per_page = (int) $total_number_of_posts;
			if ( -1 == $total_number_of_posts ) {
				$feeds_object->posts_per_page = 1000;
			}
		} else {
			$feeds_object->posts_per_page = (int) $no_of_posts_per_page;
		}

		$feeds_object->cur_page          = (int) ( $cur_page );
		
		$pages_to_display_for_pagination = apply_filters( 'pages_to_display_for_pagination', 7, 10 );
		$pagination                      = '0';
		// Set pagination to yes.
		if ( ( 'paged' === $ssd_pagination_type || 'load_more_btn' === $ssd_pagination_type || 'load_onscroll_btn' === $ssd_pagination_type ) && $total_feeds > $no_of_posts_per_page && ( 'listing' === $layout || 'timeline' === $layout ) ) {
			$pagination = '1';
		}

		// Set pagination to 1000 to display all linked pages in pagination instead of 7.
		if ( 'load_more_btn' === $ssd_pagination_type || 'load_onscroll_btn' === $ssd_pagination_type ) {
			$pages_to_display_for_pagination = apply_filters( 'pages_to_display_for_pagination', 1000, 10 );
		}
		// Get all feeds.
		$feed_title_array = array();
		$social_stream    = $feeds_object->ssd_get_stream();
		if ( is_array( $social_stream ) && ! empty( $social_stream ) ) {
			foreach ( $social_stream as $feeds ) {
				$feed_title_data[] = $feeds->feed_type;
			}
			if ( is_array( $feed_title_data ) && ! empty( $feed_title_data ) ) {
				$feed_title_array = array_unique( $feed_title_data );
			}
		}

		$display_data = Social_Stream_Main::ssd_ispossible_display_data( $ssd_display_private_stream, $ssd_hide_desktop_stream, $ssd_hide_mobile_stream );
		ob_start();
		include SOCIALSTREAMDESIGNER_DIR . 'css/layout-dynamic-style.php';
		/**
		 * Display Export layout button
		 */
		global $wp;
        $current_url = home_url(add_query_arg(array(), $wp->request));
		?>
		<div class="layout_export_butto" style="display:none;">
			<a class="ssd-button ssd-button ssd-is-primary" href="<?php echo $current_url.'?action=demoexport&id='.$shortcode_id; ?>" title=" Export Demo Layout">Export Feed Layout</a>
		</div>
		<?php
		if ( $display_data ) {
			?>
			<?php if ( ! empty( $ssd_stream_title ) || ! empty( $ssd_stream_subtitle ) ) { ?>
				<div class="sstrm-hed-wrp" id="social_stream_header_<?php echo '_' . intval( $shortcode_id ); ?>">
					<?php if ( ! empty( $ssd_stream_title ) ) { ?>
						<div class="ssd-steam-title-wrap">
							<h1><?php echo esc_html( $ssd_stream_title ); ?></h1>
						</div>
					<?php } ?>
					<?php if ( ! empty( $ssd_stream_subtitle ) ) { ?>
						<div class="ssd-steam-sub-title-wrap">
							<h4><?php echo esc_html( $ssd_stream_subtitle ); ?></h4>
						</div>
					<?php } ?>
					<?php if ( isset( $ssd_display_search ) && 1 == $ssd_display_search && 'listing' === $layout ) { ?>
						<div class="ssd_search">
							<input type="text" value="" name="s" placeholder="<?php esc_html_e( 'Search', 'social-stream-designer' ); ?>" class="ssd_search_box">
							<input type="hidden" value="<?php echo $shortcode_id; ?>" name="ssd_id">
						</div>
					<?php } ?>
				</div>

			<?php } ?>
			<div class="ssdsos-wrp ssd-content" data-id="<?php echo intval( $shortcode_id ); ?>" id="social_stream_<?php echo '_' . intval( $shortcode_id ); ?>">
				<?php
				$filter_class = '';
				if ( empty( $ssd_stream_title ) && empty( $ssd_stream_subtitle ) && 'listing' === $layout ) {
					if ( isset( $ssd_display_search ) && 1 == $ssd_display_search ) {
						?>
						<div class="ssd_search">
							<input type="text" value="" name="s" placeholder="<?php esc_html_e( 'Search', 'social-stream-designer' ); ?>" class="ssd_search_box">
							<input type="hidden" value="<?php echo $shortcode_id; ?>" name="ssd_id">
						</div>
						<?php
					}
				}
				if ( 'listing' === $layout && 1 == $ssd_display_filter ) {
					$filter_class = 'ssd-enable-filter';
					?>
						<div class="ssd-feed-filter">
							<ul>
								<li class="filter-all" data-cat="*">
									<a class="ssd_active-feed" href="javascript:void(0)"><?php esc_html_e( 'All', 'social-stream-designer' ); ?></a>
								</li>
								<?php
								$fb_style = $twr_style = $pr_style = $ig_style = $fr_style = $vmo_style = $yte_style = $rss_style = $dble_style = $fsqr_style = $tmblr_style = $wpress_style = $sclud_style = 'display: none;';
								if ( in_array( 'facebook', $feed_title_array, true ) ) {
									$fb_style = 'display: inline-block;';
								}
								if ( in_array( 'twitter', $feed_title_array, true ) ) {
									$twr_style = 'display: inline-block;';
								}
								if ( in_array( 'pinterest', $feed_title_array, true ) ) {
									$pr_style = 'display: inline-block;';
								}
								if ( in_array( 'instagram', $feed_title_array, true ) ) {
									$ig_style = 'display: inline-block;';
								}
								if ( in_array( 'flickr', $feed_title_array, true ) ) {
									$fr_style = 'display: inline-block;';
								}
								if ( in_array( 'vimeo', $feed_title_array, true ) ) {
									$vmo_style = 'display: inline-block;';
								}
								if ( in_array( 'youtube', $feed_title_array, true ) ) {
									$yte_style = 'display: inline-block;';
								}
								if ( in_array( 'rss', $feed_title_array, true ) ) {
									$rss_style = 'display: inline-block;';
								}
								if ( in_array( 'dribbble', $feed_title_array, true ) ) {
									$dble_style = 'display: inline-block;';
								}
								if ( in_array( 'foursquare', $feed_title_array, true ) ) {
									$fsqr_style = 'display: inline-block;';
								}
								if ( in_array( 'tumblr', $feed_title_array, true ) ) {
									$tmblr_style = 'display: inline-block;';
								}
								if ( in_array( 'WordPress', $feed_title_array, true ) ) {
									$wpress_style = 'display: inline-block;';
								}
								if ( in_array( 'soundcloud', $feed_title_array, true ) ) {
									$sclud_style = 'display: inline-block;';
								}
								?>
								<li class="filter-facebook" data-cat="filter-facebook" style="<?php echo $fb_style; ?>">
									<a title="<?php echo esc_html( 'Facebook' ); ?>" href="javascript:void(0)"><i class="fab fa-facebook-f"></i></a>
								</li>
								<li class="filter-twitter" data-cat="filter-twitter" style="<?php echo $twr_style; ?>">
									<a title="<?php echo esc_html( 'Twitter' ); ?>" href="javascript:void(0)"><i class="fab fa-twitter"></i></a>
								</li>
								<li class="filter-pinterest" data-cat="filter-pinterest" style="<?php echo $pr_style; ?>">
									<a title="<?php echo esc_html( 'Pinterest' ); ?>" href="javascript:void(0)"><i class="fab fa-pinterest"></i></a>
								</li>
								<li class="filter-instagram" data-cat="filter-instagram" style="<?php echo $ig_style; ?>">
									<a title="<?php echo esc_html( 'Instagram' ); ?>" href="javascript:void(0)"><i class="fab fa-instagram"></i></a>
								</li>
								<li class="filter-flickr" data-cat="filter-flickr" style="<?php echo $fr_style; ?>">
									<a title="<?php echo esc_html( 'Flickr' ); ?>" href="javascript:void(0)"><i class="fab fa-flickr"></i></a>
								</li>
								<li class="filter-vimeo" data-cat="filter-vimeo" style="<?php echo $vmo_style; ?>">
									<a title="<?php echo esc_html( 'Vimeo' ); ?>" href="javascript:void(0)"><i class="fab fa-vimeo"></i></a>
								</li>
								<li class="filter-youtube" data-cat="filter-youtube" style="<?php echo $yte_style; ?>">
									<a title="<?php echo esc_html( 'YouTube' ); ?>" href="javascript:void(0)"><i class="fab fa-youtube"></i></a>
								</li>
								<li class="filter-rss" data-cat="filter-rss" style="<?php echo $rss_style; ?>">
									<a title="<?php echo esc_html( 'RSS' ); ?>" href="javascript:void(0)"><i class="fas fa-rss"></i></a>
								</li>
								<li class="filter-dribbble" data-cat="filter-dribbble" style="<?php echo $dble_style; ?>">
									<a title="<?php echo esc_html( 'Dribbble' ); ?>" href="javascript:void(0)"><i class="fab fa-dribbble"></i></a>
								</li>
								<li class="filter-foursquare" data-cat="filter-foursquare" style="<?php echo $fsqr_style; ?>">
									<a title="<?php echo esc_html( 'Foursquare' ); ?>" href="javascript:void(0)"><i class="fab fa-foursquare"></i></a>
								</li>
								<li class="filter-tumblr" data-cat="filter-tumblr" style="<?php echo $tmblr_style; ?>">
									<a title="<?php echo esc_html( 'Tumblr' ); ?>" href="javascript:void(0)"><i class="fab fa-tumblr"></i></a>
								</li>
								<li class="filter-wordpress" data-cat="filter-wordpress" style="<?php echo $wpress_style; ?>">
									<a title="<?php echo esc_html( 'WordPress' ); ?>" href="javascript:void(0)"><i class="fab fa-wordpress-simple"></i></a>
								</li>
								<li class="filter-soundcloud" data-cat="filter-soundcloud" style="<?php echo $sclud_style; ?>">
									<a title="<?php echo esc_html( 'Sound Cloud' ); ?>" href="javascript:void(0)"><i class="fab fa-soundcloud"></i></a>
								</li>
							</ul>
						</div>
						<?php
				}
				$style = '';
				if ( 'slider' === $layout && 'vertical' === $ssd_slider_direction ) {
					$ssd_slider_widthpx = $ssd_slider_width . 'px';
					$style              = "style = max-width:$ssd_slider_widthpx";
				}
				?>
					<div <?php echo esc_attr( $style ); ?> class="ssd-wrapper-inner 
						<?php
						echo 'ssd_' . esc_attr( $ssd_pagination_type );
						if ( 'slider' === $layout ) {
							echo ' slickslider';
						}
						?>
					">
						<div id="ssd_social_stream_<?php echo esc_attr( $layout ); ?>"
							class="ssd-cnt-prnt  ssd-row-padding slides 
							<?php
							echo esc_attr( 'ssd_social_stream_' . $layout ) . ' ' . esc_attr( $filter_class ) . ' ';
							if ( 'timeline' === $layout ) {
								echo ' ssdss_tmln';
							}
							?>
							ssd_social_stream_<?php echo esc_attr( $ssd_grid_style ); ?>" >
								<?php
								if ( is_array( $social_stream ) && ! empty( $social_stream ) ) {
									foreach ( $social_stream as $feeds ) {
										foreach ( $feed_live_status as $key => $val ) {
											$c_feed_id = (int) $feeds->feed_id;
											if ( $key == $c_feed_id ) {
												$image = isset( $feeds->post_image ) ? $feeds->post_image : '';
												$video = isset( $feeds->post_video ) ? $feeds->post_video : '';
												if ( 1 == $ssd_display_feed_without_media ) {
													include 'include/social-stream-layout.php';
												} else {
													if ( '' !== $image || '' !== $video ) {
														include 'include/social-stream-layout.php';
													}
												}
											}
										}
									}
								}
								?>
						</div>
						<?php
						// Display Pagination.
						if ( $no_of_posts_per_page < $ssd_total_stream ) {
							if ( is_array( $social_stream ) && ! empty( $social_stream ) && ( $total_number_of_posts > $no_of_posts_per_page || -1 == $total_number_of_posts ) ) {
								echo '<div class="ssd_pagination_wrap">';
								if ( 1 == $pagination ) {
									$cur_page_for_pagination = 0;
									if ( $cur_page > $pages_to_display_for_pagination ) {
										$cur_page_for_pagination = floor( $cur_page / $pages_to_display_for_pagination );
									}
									$total_pages_for_pagination = ceil( $total_feeds / $no_of_posts_per_page );
									$out_pagination             = Social_Stream_Main::ssd_get_feed_pagination( $social_stream_settings, $total_pages_for_pagination, $cur_page, $cur_page_for_pagination, $pages_to_display_for_pagination );
									echo $out_pagination;
								}
								if ( ( 'load_more_btn' === $ssd_pagination_type ) && 'listing' === $layout ) {
									$ssd_pagination_layout = ( isset( $social_stream_settings['ssd_load_more_layout'] ) && '' !== $social_stream_settings['ssd_load_more_layout'] ) ? $social_stream_settings['ssd_load_more_layout'] : 'template-1';
									?>
									<button class="ssd_social_stream_load_more_btn <?php echo esc_attr( $ssd_pagination_layout ); ?> ssd-button ssd-black ssd-margin-bottom"><?php esc_html_e( 'Load More', 'social-stream-designer' ); ?></button>
																							<?php
								}
								echo '</div>';
							}
						}
						?>
						<div class="ssd-prev-next">
							<?php
							if ( 1 == $ssd_display_slider_playpause && 'slider' === $layout ) {
								$class = 'ssd-play fa fa-play';
								if ( 1 == $ssd_display_autoplay ) {
									$class = 'ssd-pause fa fa-pause';
								}
								?>
								<i class="slick-arrow ssd-play-pause <?php echo esc_attr( $class ); ?>"></i>
							<?php } ?>
						</div>
					</div>
				</div>
				<?php
		}
		if ( 'slider' === $layout ) {
			?>
			<script>
				jQuery('.ssd-cnt-prnt').imagesLoaded(function(){
				jQuery(".slickslider .ssd-cnt-prnt").slick({autoplay: <?php echo ( 1 == $ssd_display_autoplay ) ? 'true' : 'false'; ?>,autoplaySpeed: <?php echo esc_attr( $ssd_slider_interval ); ?>,rtl: false,arrows: <?php echo ( 1 == $ssd_display_slider_nav ) ? 'true' : 'false'; ?>,speed : <?php echo esc_attr( $ssd_slider_speed ); ?>,slidesPerRow: 1,
				<?php if ( 'vertical' === $ssd_slider_direction ) { ?>
					slidesToShow: <?php echo esc_attr( $ssd_column_type_vertical ); ?>,centerPadding: '0px',
					<?php
				} else {
					?>
					centerPadding: '0px',
							rows : <?php echo esc_attr( $ssd_row_type ); ?>,
							slidesToShow: <?php echo esc_attr( $ssd_column_type ); ?>,
							responsive: [
							{breakpoint: 1200,settings: {slidesToShow: <?php echo esc_attr( $ssd_column_type_laptop ); ?>}},
							{breakpoint: 1024,settings: {slidesToShow: <?php echo esc_attr( $ssd_column_type_rotated_tablet ); ?>}},
							{breakpoint: 767,settings: {slidesToShow: <?php echo esc_attr( $ssd_column_type_tablet ); ?>}},
							{breakpoint: 480,settings: {slidesToShow: <?php echo esc_attr( $ssd_column_type_rotated_mobile ); ?>}},
							{breakpoint: 380,settings: {slidesToShow: <?php echo esc_attr( $ssd_column_type_mobile ); ?>}},
							],
							<?php
				}
				?>
//				initialSlide: 2,
				slidesToScroll:1,
				<?php if ( 'vertical' === $ssd_slider_direction ) { ?>
					vertical:true,verticalSwiping:true,
				<?php } ?>
				adaptiveHeight:true,appendArrows:jQuery('.ssd-prev-next'),prevArrow:'<i class="fa fa-angle-left"></i>',nextArrow:'<i class="fa fa-angle-right"></i>',
				});
				});
			</script>
				<?php
		}
		?>
			<script>
				jQuery('.ssd-cnt-prnt').imagesLoaded(function(){
				jQuery(".ssd-carousel-media > .slides").slick({
				autoplay: <?php echo ( 1 == $ssd_display_media_autoplay ) ? 'true' : 'false'; ?>,
						autoplaySpeed: <?php echo esc_attr( $ssd_slider_media_interval ); ?>,
						rtl: <?php echo ( is_rtl() ? 'true' : 'false' ); ?>,
						arrows: <?php echo ( 1 == $ssd_display_media_slider_arrows ) ? 'true' : 'false'; ?>,
						speed : <?php echo esc_attr( $ssd_slider_media_speed ); ?>,
						slidesPerRow: 1,slidesToShow: 1,slidesToScroll: 1,adaptiveHeight: false,prevArrow : '<span class="prev-arrow"><i class="fa fa-angle-left"></i></span>',nextArrow : '<span class="next-arrow"><i class="fa fa-angle-right"></i></span>',
				});
				});
			</script>
			<?php
			$output_string = ob_get_contents();
			ob_end_clean();
			return $output_string;
	}

	/**
	 * Replace WordPress Feed type
	 *
	 * @since    1.0.0
	 */
	public function ssd_replace_wordpress_feed() {
		global $wpdb;
		$wpdb->update( $wpdb->prefix . 'ssd_feed_posts', array( 'feed_type' => 'wordpress' ), array( 'feed_type' => 'WordPress' ) );
	}

	/**
	 * Create menus at admin side
	 *
	 * @return void
	 */
	public function ssd_add_menu() {
		$hook = add_menu_page( esc_html( 'Social Stream Designer' ), esc_html( 'Social Stream Designer' ), 'manage_options', 'social-stream-designer-layouts', '', 'dashicons-layout' );
		add_action( "load-$hook", array( $this, 'ssd_add_option' ) );
		add_submenu_page( 'social-stream-designer-layouts', esc_html__( 'Social Stream Layouts', 'social-stream-designer' ), esc_html__( 'Layouts', 'social-stream-designer' ), 'manage_options', 'social-stream-designer-layouts', array( $this, 'ssd_get_layout_function' ) );
		add_submenu_page( 'social-stream-designer-layouts', esc_html__( 'Add Social Stream Layouts', 'social-stream-designer' ), esc_html__( 'Add New Layout', 'social-stream-designer' ), 'manage_options', 'social-stream-designer-add-layouts', array( $this, 'ssd_add_layout_function' ) );
		$feed_hook = add_submenu_page( 'social-stream-designer-layouts', esc_html__( 'Social Feeds', 'social-stream-designer' ), esc_html__( 'Social Feeds', 'social-stream-designer' ), 'manage_options', 'social-stream-designer-social-feed-layouts', array( $this, 'ssd_get_social_feed_function' ) );
		add_action( "load-$feed_hook", array( $this, 'ssd_feed_add_option' ) );
		add_submenu_page( 'social-stream-designer-layouts', esc_html__( 'Add Social Feed', 'social-stream-designer' ), esc_html__( 'Add Social Feed', 'social-stream-designer' ), 'manage_options', 'social-stream-designer-social-feed', array( $this, 'ssd_add_social_feed_function' ) );
		add_submenu_page( 'social-stream-designer-layouts', esc_html__( 'Social Authentication', 'social-stream-designer' ), esc_html__( 'Social Authentication', 'social-stream-designer' ), 'manage_options', 'social-stream-designer-settings', array( $this, 'ssd_settings_function' ) );
		add_submenu_page( 'social-stream-designer-layouts', esc_html__( 'Getting started', 'social-stream-designer' ), esc_html__( 'Getting started', 'social-stream-designer' ), 'manage_options', 'social-stream-designer-started', array( $this, 'ssd_getting_started_function' ) );
	}
	/**
	 * Ssd Layout Preview.
	 *
	 * @return void
	 */
	public function ssd_design_preview_request() {
		ob_start();
		require_once SOCIALSTREAMDESIGNER_DIR . 'include/ssd-designer-preview.php';
		$o = ob_get_clean();
		echo wp_kses( $o, self::args_kses() );
		die();
	}
	/**
	 * Language text domain.
	 *
	 * @return void
	 */
	public function ssd_load_language_files() {
		load_plugin_textdomain( 'social-stream-designer', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
	}
	/**
	 * Set item per page
	 *
	 * @param string $status status.
	 * @param string $option option.
	 * @param string $value value.
	 * @return string
	 */
	public function ssd_set_option( $status, $option, $value ) {
		if ( 'ssd_items_per_page' === $option || 'ssd_feeds_per_page' === $option ) {
			return $value;
		}

		return $status;
	}
	/**
	 * Add item per page
	 *
	 * @return void
	 */
	public function ssd_add_option() {
		$option = 'per_page';
		$args   = array(
			'label'   => 'Number of items per page',
			'default' => 10,
			'option'  => 'ssd_items_per_page',
		);
		add_screen_option( $option, $args );
	}
	/**
	 * Add Feed per page
	 *
	 * @return void
	 */
	public function ssd_feed_add_option() {

		$option = 'per_page';
		$args   = array(
			'label'   => 'Number of items per page',
			'default' => 10,
			'option'  => 'ssd_feeds_per_page',
		);
		add_screen_option( $option, $args );
	}
	/**
	 * Display all created layouts at admin side
	 *
	 * @return void
	 */
	public function ssd_get_layout_function() {
		$shortcode_list_table = new Shortcode_List_Table();
		$shortcode_list_table->prepare_items();
		if ( isset( $_POST['nonce'] ) ) {
			$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );
			if ( ! wp_verify_nonce( $nonce, 'layout-nonce' ) ) {
				wp_send_json_error( array( 'status' => 'Nonce error' ) );
				die();
			}
		}
		?>
		<div class="wrap">
			<div>
				<h1 class="wp-heading-inline"><?php esc_html_e( 'Social Stream Layouts', 'social-stream-designer' ); ?></h1>
				<div class="ssd-button-wrap">
					<?php add_thickbox(); ?>
					<a href="<?php echo esc_url( admin_url( 'admin.php?page=social-stream-designer-add-layouts' ) ); ?>" class="ssd-button ssd-is-primary page-title-action"><?php esc_html_e( 'Add New Social Stream Layout', 'social-stream-designer' ); ?></a>

					<a title="<?php _e('Import Demo Layout', 'social-stream-designer'); ?>" class="ssd-button ssd-is-secondary ssd-import-layout mr5 thickbox" href="#TB_inline?width=250&height=90&inlineId=import_demo_layout" data-toggle="modal" data-target="#import_demo_layout"><?php _e('Import Demo Layout', 'social-stream-designer'); ?> </a>
				</div>
				
				<?php
				if ( isset( $_REQUEST['delete'] ) && 'true' == $_REQUEST['delete'] ) {
					?>
				<div class="updated notice">
					<p>
					<?php
						esc_html_e( 'Layout has been deleted successfully.', 'social-stream-designer' );
					?>
					</p>
				</div>
					<?php
				} elseif ( isset( $_REQUEST['delete'] ) && 'false' == $_REQUEST['delete'] ) {
					?>
				<div class="error notice">
					<p>
					<?php
						esc_html_e( 'Error to delete layout.', 'social-stream-designer' );
					?>
					</p>
				</div>
					<?php
				}
				?>
			</div>
			<form id="shortcode-filter" method="get">
				<?php
				$page = isset( $_REQUEST['page'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['page'] ) ) : '';
				?>
				<input type="hidden" name="page" value="<?php echo esc_attr( $page ); ?>" />
				<?php $shortcode_list_table->display(); ?>
			</form>
			<div id="import_demo_layout" class="modal fade import_demo_layout" role="dialog" style="display:none;">
                <div class="modal-dialog import_layout">
                    <div class="modal-content">
                        <div class="modal-body">
                            <form enctype="multipart/form-data" name="ssd_demo_layout_import" id="ssd_demo_layout_import" method="post">
                                <?php wp_nonce_field('ssd_demo_import', 'ssd_demo_import_nonce'); ?>
                                <input type="file" name="ssd_demo_layout_import_file" id="ssd_demo_layout_import_file"/>
                                <input type="submit" name="ssd_file_demo_import" id="ssd_file_demo_import" value="Submit" class="hidden" />
                            </form>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-primary button button-primary" id="save_demo_import_layout"><?php _e('Import Layout', 'social-stream-designer'); ?></button>
                        </div>
                    </div>
                </div>
            </div>
		</div>
		<?php
	}
	/**
	 * Display all feeds at admin side
	 *
	 * @return void
	 */
	public function ssd_get_social_feed_function() {
		$feed_list_table = new Feed_List_Table();
		$feed_list_table->prepare_items();
		if ( isset( $_POST['nonce'] ) ) {
			$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );
			if ( ! wp_verify_nonce( $nonce, 'feed-list-table-nonce' ) ) {
				wp_send_json_error( array( 'status' => 'Nonce error' ) );
				die();
			}
		}
		?>
		<div class="wrap">
			<div>
				<h1 class="wp-heading-inline"><?php esc_html_e( 'Social Feeds', 'social-stream-designer' ); ?></h1>
				<a href="<?php echo esc_url( admin_url( 'admin.php?page=social-stream-designer-social-feed' ) ); ?>" class="page-title-action"><?php esc_html_e( 'Add New Social Feed', 'social-stream-designer' ); ?></a>
			</div>
			<?php
			if ( isset( $_REQUEST['delete'] ) && 'true' == $_REQUEST['delete'] ) {
				global $wpdb;
				$feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
				$feed_id          = ( isset( $_GET['id'] ) && '' !== $_GET['id'] ) ? intval( $_GET['id'] ) : '';
				$wpdb->delete( $feed_posts_table, array( 'feed_id' => $feed_id ), array( '%d' ) );
				?>
				<div class="updated notice">
					<p>
					<?php
					esc_html_e( 'Feed has been deleted successfully.', 'social-stream-designer' );
					?>
					</p>
				</div>
				<?php
			} elseif ( isset( $_REQUEST['delete'] ) && 'false' == $_REQUEST['delete'] ) {
				?>
				<div class="error notice">
					<p>
				<?php
				esc_html_e( 'Error to delete feed.', 'social-stream-designer' );
				?>
					</p>
				</div>
				<?php
			}
			?>
			<form id="shortcode-filter" method="get">
				<?php $page = isset( $_REQUEST['page'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['page'] ) ) : ''; ?>
				<input type="hidden" name="page" value="<?php echo esc_attr( $page ); ?>" />
				<?php $feed_list_table->display(); ?>
			</form>
		</div>
		<?php
	}
	/**
	 * Include file for social feeds tab
	 *
	 * @return void
	 */
	public function ssd_add_social_feed_function() {
		include_once 'admin/assets/social-stream-add-social-feed.php';
	}
	/**
	 * Include file for social layouts tab
	 *
	 * @return void
	 */
	public function ssd_add_layout_function() {
		include_once 'admin/assets/social-stream-add-layout.php';
	}
	/**
	 * Include file for social settings tab
	 *
	 * @return void
	 */
	public function ssd_settings_function() {
		include_once 'admin/assets/social-stream-settings-form.php';
	}
	/**
	 * Include file for Getting started tab
	 *
	 * @return void
	 */
	public function ssd_getting_started_function() {
		include_once 'admin/assets/social-stream-getting-started.php';
	}
	/**
	 * Add scripts and styles at admin side
	 *
	 * @return void
	 */
	public function ssd_admin_script_style() {
		if ( isset( $_GET['page'] ) && ( 'social-stream-designer-layouts' === $_GET['page'] || 'social-stream-designer-add-layouts' === $_GET['page'] || 'social-stream-designer-social-feed-layouts' === $_GET['page'] || 'social-stream-designer-social-feed' === $_GET['page'] || 'social-stream-designer-settings' === $_GET['page'] || 'social-stream-designer-started' === $_GET['page'] ) ) {
			wp_enqueue_style( 'ssd_admin_style', SOCIALSTREAMDESIGNER_URL . '/admin/css/admin-style.css', array(), '1.0', false );
			if( is_rtl() ) {
				wp_enqueue_style( 'ssd_admin_rtl_style', SOCIALSTREAMDESIGNER_URL . '/admin/css/admin-style-rtl.css', array(), '1.0', false );
			}
			wp_enqueue_style( 'ssd_fontawesome', SOCIALSTREAMDESIGNER_URL . '/css/fontawesome-all.min.css', array(), '1.0', false );
			wp_enqueue_style( 'ssd_admin_select2', SOCIALSTREAMDESIGNER_URL . '/admin/css/select2.min.css', array(), '1.0', false );
			wp_enqueue_style( 'wp-jquery-ui-dialog' );
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_style( 'ssd_justify', SOCIALSTREAMDESIGNER_URL . '/css/justifiedGallery.min.css', array(), '1.0', false );
			wp_enqueue_script( 'ssd_admin_select2', SOCIALSTREAMDESIGNER_URL . '/admin/js/select2.min.js', array( 'jquery' ), '1.0', true );
			wp_enqueue_media();
			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'jquery-ui-core' );
			wp_enqueue_script( 'jquery-ui-dialog' );
			wp_enqueue_script( 'jquery-ui-sortable' );
			wp_enqueue_script( 'wp-color-picker' );
			wp_enqueue_script( 'ssd_wpcolorpicker_alpha', SOCIALSTREAMDESIGNER_URL . '/admin/js/wp-color-picker-alpha.js', array( 'wp-color-picker' ), '1.0', true );
			wp_enqueue_script( 'ssd_admin_script', SOCIALSTREAMDESIGNER_URL . '/admin/js/admin-script.js', array( 'jquery' ), '1.0', false );
			$ssd_colorpicker = array('theme_path' => get_stylesheet_directory_uri() . '/', 'clear' => esc_html__('Clear', 'social-stream-designer'), 'defaultString' => esc_html__('Default', 'social-stream-designer'), 'pick' => esc_html__('Select Color', 'social-stream-designer'));
        	wp_localize_script('wp-color-picker', 'wpColorPickerL10n', $ssd_colorpicker);
			wp_localize_script(
				'ssd_admin_script',
				'ssd_ajax_var',
				array(
					'ssd_nonce' => wp_create_nonce( 'ssd_nonce_ajax' ),
					'import_error_txt_only'       => __( 'Import only .txt file generated by this plugin', 'social-stream-designer' ),
					'import_error_no_file_select' => __( 'No file selected for import.', 'social-stream-designer' ),
				)
			);
			wp_enqueue_script( 'ssd_modernizr_custom', SOCIALSTREAMDESIGNER_URL . '/js/modernizr.custom.js', array( 'jquery' ), '1.0', false );
			wp_enqueue_script( 'jquery-masonry' );
			wp_enqueue_script( 'ssd_justify', SOCIALSTREAMDESIGNER_URL . '/js/jquery.justifiedGallery.min.js', array( 'jquery' ), '1.0', false );
			wp_enqueue_script( 'ssd_classie', SOCIALSTREAMDESIGNER_URL . '/js/classie.min.js', array( 'jquery' ), '1.0', false );
			wp_enqueue_script( 'ssd_anim_on_scroll', SOCIALSTREAMDESIGNER_URL . '/js/AnimOnScroll.js', array( 'jquery', 'jquery-masonry' ), '1.0', false );
			wp_localize_script(
				'ssd_anim_on_scroll',
				'ssdanimobj',
				array(
					'is_rtl'                      => ( is_rtl() ) ? true : false,
				)
			);
			wp_localize_script(
				'ssd_admin_script',
				'ssdadminObj',
				array(
					'reset_data'           => esc_html__( 'Do you want to reset data?', 'social-stream-designer' ),
					'select_social_stream' => esc_html__( 'Please select social stream.', 'social-stream-designer' ),
					'validation_error'     => esc_html__( 'Please enter numeric value. Fill the red border input correct and try again.', 'social-stream-designer' ),
					'delete_confirm'       => esc_html__( 'Are you sure to delete this item?', 'social-stream-designer' ),
					'preview_title'        => esc_html__( 'Your Social Stream Layout Preview', 'social-stream-designer' ),
					'ssd_plugin_path'      => SOCIALSTREAMDESIGNER_URL,
					'is_rtl'                      => ( is_rtl() ) ? true : false,
				)
			);
		}
	}
	/**
	 * Save feeds at admin side
	 *
	 * @return void
	 */
	public function ssd_save_admin_template() {
		if ( current_user_can( 'manage_options' ) ) {
			if ( isset( $_POST['ssd'] ) ) {
				if ( isset( $_POST['ssd_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['ssd_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
					$ssd_layout_actions = new SSDLayoutsActions();
					$ssd_layout_actions->init();
					$ssd_layout_actions->ssd_add_layout();
				}
			} elseif ( isset( $_POST['feed_stream_nonce'] ) ) {
				if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
					$ssd_feeds_actions = new SSDFeedsActions();
					$ssd_feeds_actions->init();
					$ssd_feeds_actions->ssd_add_feed();
				}
			} elseif ( isset( $_POST['social-stream-designer-settings'] ) ) {
				$error_array      = array();
				$update_auth_name = '';
				if ( isset( $_POST['social-stream-designer-settings'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['social-stream-designer-settings'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
					foreach ( $_POST as $key => $value ) {
						if ( 'facebook_stream' === $key ) {
							$update_auth_name      = 'Facebook';
							$facebook_id           = $value['facebook_id'];
							$facebook_secret       = $value['facebook_secret'];
							$facebook_access_token = $value['facebook_access_token'];
							$url                   = 'https://graph.facebook.com/oauth/access_token?client_id=' . $facebook_id . '&client_secret=' . $facebook_secret . '&grant_type=fb_exchange_token&fb_exchange_token=' . $facebook_access_token;
							$get_message           = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();
							$response              = json_decode( $get_message, true );
							if ( isset( $response['error']['message'] ) && ! empty( $response['error']['message'] ) ) {
								$error_array[] = $response['error']['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' Facebook stream' );
							} else {
								if ( ! $response ) {
									$error_array[] = 'Facebook Stream';
								}
							}
						} elseif ( 'youtube_stream' === $key ) {
							$update_auth_name = 'YouTube';
							$youtube_key      = $value['youtube_key'];
							$url              = 'https://www.googleapis.com/youtube/v3/search?part=snippet&q=YouTube+Data+API&type=video&key=' . $youtube_key;
							$get_message      = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
							$response         = json_decode( $get_message, true );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();
							if ( isset( $response['error']['message'] ) && '' !== $response['error']['message'] ) {
								$error_array[] = $response['error']['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' youtube stream' );
							}
							if ( is_array( $get_php_error ) ) {
								if ( $get_php_error ) {
									$error_array[] = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' youtube stream' );
								} else {
									if ( ! $response ) {
										$error_array[] = 'Youtube Stream';
									}
								}
							} else {
								if ( ! $response ) {
									$error_array[] = 'Youtube Stream';
								}
							}
						} elseif ( 'flickr_stream' === $key ) {
							$update_auth_name = 'Flickr';
							$flickr_apikey    = $value['api_key'];
							$flickr_apisecret    = $value['api_secret'];
							$url           = 'https://api.flickr.com/services/rest/?method=flickr.test.echo&api_key=' . $flickr_apikey . '&format=json&nojsoncallback=1';
							$get_message   = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
							$response      = json_decode( $get_message, true );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();

							if ( isset( $response['message'] ) && ! empty( $response['message'] ) ) {
								$error_array[] = $response['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' flickr stream' );
							} elseif ( is_array( $get_php_error ) ) {
								if ( $get_php_error ) {
									$error_array[] = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' flickr stream' );
								} else {
										$error_array[] = 'Flickr stream';
								}
							} else {
								if ( 'fail' === $response['stat'] ) {
									$error_array[] = 'Flickr stream';
								}
							}
						} elseif ( 'instagram_stream' === $key ) {
							$update_auth_name = 'Instagram';
							$access_token     = $value['access_token'];

							$url           = 'https://graph.instagram.com/me/media?fields=id,caption&access_token=' . $access_token;
							$get_message   = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
							$response      = json_decode( $get_message, true );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();
							if ( isset( $response['meta']['error_message'] ) && ! empty( $response['meta']['error_message'] ) ) {
								$error_array[] = $response['meta']['error_message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' instagram stream' );
							} else {
								if ( ! $response ) {
									$error_array[] = 'Instagram Stream';
								}
							}
						} elseif ( 'twitter_stream' === $key ) {
							$update_auth_name          = 'Twitter';
							$oauth_access_token        = $value['access_token'];
							$oauth_access_token_secret = $value['access_token_secret'];
							$consumer_key              = $value['consumer_key'];
							$consumer_secret           = $value['consumer_secret'];
							$settings                  = array(
								'oauth_access_token' => $oauth_access_token,
								'oauth_access_token_secret' => $oauth_access_token_secret,
								'consumer_key'       => $consumer_key,
								'consumer_secret'    => $consumer_secret,
							); 
							$url                       = 'https://api.twitter.com/1.1/account/verify_credentials.json';
							$request_method            = 'GET';
							$getfield                  = '?count=20';
							$twitter                   = new TwitterAPIExchange( $settings );
							$result                    = $twitter->setGetfield( $getfield )->buildOauth( $url, $request_method )->performRequest();
							$json                      = json_decode( $result, true );
						
							$get_php_error = Social_Stream_Main::ssd_get_last_error();
							if ( isset( $json['errors']['0']['message'] ) && ! empty( $json['errors']['0']['message'] ) ) {
								$error_array[] = $json['errors']['0']['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' twitter stream' );
							} elseif ( is_array( $get_php_error ) ) {
								if ( $get_php_error ) {
									$error_array[] = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' twitter stream' );
								} else {
									$error_array[] = 'Twitter stream';
								}
							} else {
								if ( isset( $json->errors ) ) {
									$error_array[] = 'Twitter Stream';
								}
							}
						} elseif ( 'vimeo_stream' === $key ) {
							$update_auth_name  = 'Vimeo';
							$vimeo_client_id   = $value['client_id'];
							$vimeo_secrets_key = $value['secrets_key'];
							include_once SOCIALSTREAMDESIGNER_DIR . 'include/vimeoPhp/autoload.php';
							$lib           = new \Vimeo\Vimeo( $vimeo_client_id, $vimeo_secrets_key );
							$token         = $lib->clientCredentials( array( 'private', 'public', 'purchased', 'create', 'edit', 'delete', 'interact', 'upload', 'video_files' ) );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();

							if ( isset( $token['body']['error'] ) && ! empty( $token['body']['error'] ) ) {
								$error_array[] = $token['body']['error'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' vimeo stream' );
							} elseif ( is_array( $get_php_error ) ) {
								if ( $get_php_error ) {
									$error_array[] = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' vimeo stream' );
								} else {
									$error_array[] = 'Vimeo stream';
								}
							} else {
								if ( isset( $token['body']['error'] ) ) {
									$error_array[] = 'Vimeo Stream';

								}
							}
						} elseif ( 'dribbble_stream' === $key ) {
							$update_auth_name = 'Dribbble';
							$access_token     = $value['dribbble_access_token'];

							$url           = 'https://api.dribbble.com/v2/user/?access_token=' . $access_token;
							$get_message   = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
							$response      = json_decode( $get_message, true );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();
							if ( isset( $response['message'] ) && ! empty( $response['message'] ) ) {
								$error_array[] = $response['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' dribbble stream' );
							} elseif ( is_array( $get_php_error ) ) {
								if ( $get_php_error ) {
									$error_array[] = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' dribbble stream' );
								} else {
									$error_array[] = 'Dribbble stream';
								}
							} else {
								if ( ! $response ) {
									$error_array[] = 'Dribbble Stream';
								}
							}
						} elseif ( 'foursquare_stream' === $key ) {
							$update_auth_name = 'Foursquare';
							$access_token     = $value['foursquare_access_token'];
							$today_date       = gmdate( 'Ymd' );
							$url              = 'https://api.foursquare.com/v2/users/self/checkins?oauth_token=' . $access_token . '&v=' . $today_date;
							$get_message      = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
							$response         = json_decode( $get_message, true );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();
							if ( isset( $response['meta']['errorDetail'] ) && ! empty( $response['meta']['errorDetail'] ) ) {
								$error_array[] = $response['meta']['errorDetail'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' foursquare stream' );
							} elseif ( is_array( $get_php_error ) ) {
								if ( $get_php_error ) {
									$error_array[] = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' foursquare stream' );
								} else {
									$error_array[] = 'Foursquare stream';
								}
							} else {
								if ( ! $response ) {
									$error_array[] = 'Foursquare Stream';
								}
							}
						} elseif ( 'soundcloud_stream' === $key ) {
							$update_auth_name = 'SoundCloud';
							$access_token     = $value['soundcloud_access_token'];
							$url              = 'https://api.soundcloud.com/tracks?client_id=' . $access_token;
							$get_message      = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
							$response         = json_decode( $get_message, true );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();
							if ( !empty( $response['status'] ) ) {
								$error_array[] = $response['status'] .'!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ). esc_html( ' SoundCloud stream' );
							} elseif ( is_array( $get_php_error ) ) {
								if ( $get_php_error ) {
									$error_array[] = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' SoundCloud stream' );
								} else {
									$error_array[] = 'SoundCloud stream';
								}
							} else {
								if ( ! $response ) {
									$error_array[] = 'SoundCloud Stream';
								}
							}
						} elseif ( 'tumblr_stream' === $key ) {
							$update_auth_name = 'Tumblr';
							$url              = 'https://api.tumblr.com/v2/blog/' . $value['tumblr_username'] . '.tumblr.com/posts?api_key=' . $value['consumer_key'] . '&limit=1';
							$get_message      = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
							$response         = json_decode( $get_message, true );
							$get_php_error = Social_Stream_Main::ssd_get_last_error();
							if ( isset( $response['errors'][0]['title'] ) && ! empty( $response['errors'][0]['title'] ) ) {
								$error_array[] = $response['errors'][0]['title'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' tumblr stream' );
							} elseif ( is_array( $get_php_error ) ) {
								if ( $get_php_error ) {
									$error_array[] = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again for', 'social-stream-designer' ) . esc_html( ' tumblr stream' );
								} else {
									$error_array[] = 'Tumblr stream';
								}
							} else {
								if ( ! $response ) {
									$error_array[] = 'Tumblr Stream';
								}
							}
						}
						$error_array_string = maybe_serialize( $error_array );
						if ( false == get_option( 'auth_error_array' ) ) {
							add_option( 'auth_error_array', $error_array_string );
						} else {
							update_option( 'auth_error_array', $error_array_string );
						}
						$_POST['error'] = $error_array;
						if ( isset( $update_auth_name ) && '' !== $update_auth_name ) {
							$_POST['update_auth_name'] = $update_auth_name;
						}
						update_option( $key, $value );
					}
				}
			}
		}
	}
	/**
	 * Delete layout
	 *
	 * @return void
	 */
	public function ssd_delete_admin_template() {
		global $wpdb;
		if ( current_user_can( 'manage_options' ) ) {

			if ( isset( $_GET['action'] ) && 'delete' === $_GET['action'] ) {
				$id   = isset( $_REQUEST['id'] ) ? intval( $_REQUEST['id'] ) : '';
				$page = isset( $_REQUEST['page'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['page'] ) ) : '';
				if ( 'social-stream-designer-social-feed-layouts' === $page || 'social-stream-designer-layouts' === $page ) {
					if ( isset( $_POST['nonce'] ) ) {
						$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );
						if ( ! wp_verify_nonce( $nonce, 'delete-admin-template-nonce' ) ) {
							wp_send_json_error( array( 'status' => 'Nonce error' ) );
							die();
						}
					}
				}
				if ( 'social-stream-designer-social-feed-layouts' === $page ) {
					$result = $wpdb->query( $wpdb->prepare( "DELETE FROM $wpdb->prefix" . 'ssd_feeds WHERE id= %d', $id ) );
					wp_safe_redirect( add_query_arg( 'id', $id, admin_url( 'admin.php?page=social-stream-designer-social-feed-layouts&delete=true' ) ) );
					exit();
				} elseif ( 'social-stream-designer-layouts' === $page ) {
					$result = $wpdb->query( $wpdb->prepare( "DELETE FROM $wpdb->prefix" . 'ssd_shortcodes WHERE ID= %d', $id ) );
					wp_safe_redirect( add_query_arg( 'id', $id, admin_url( 'admin.php?page=social-stream-designer-layouts&delete=true' ) ) );
					exit();
				}
			}
		}
	}

	/**
	 * Duplicate layout
	 *
	 * @return void
	 */
	public function ssd_duplicate_admin_template() {
		if ( current_user_can( 'manage_options' ) ) {

			if ( isset( $_GET['action'] ) && 'duplicate' === $_GET['action'] ) {
				global $wpdb;
				$id        = isset( $_GET['id'] ) ? intval( $_GET['id'] ) : '0';
				$page      = isset( $_GET['page'] ) ? sanitize_text_field( wp_unslash( $_GET['page'] ) ) : '';
				$tablename = $wpdb->prefix . 'ssd_shortcodes';
				if ( 'social-stream-designer-layouts' === $page && $id > 0 ) {
					if ( isset( $_POST['nonce'] ) ) {
						$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );
						if ( ! wp_verify_nonce( $nonce, 'duplicate-admin-template-nonce' ) ) {
							wp_send_json_error( array( 'status' => 'Nonce error' ) );
							die();
						}
					}
					$source_records = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_shortcodes where ID = %d', $id ) );
					if ( $source_records ) {
						$source_shortcode_name                            = $source_records->shortcode_name . ' - Copy';
						$source_social_stream_name                        = $source_records->social_stream_name;
						$source_social_stream_settings                    = maybe_unserialize( $source_records->social_stream_settings );
						$source_social_stream_settings['ssd_stream_page'] = '';
						$source_social_stream_name                        = $source_social_stream_name . ' - Copy';
						$wpdb->insert(
							$tablename,
							array(
								'shortcode_name'         => sanitize_text_field( $source_shortcode_name ),
								'social_stream_name'     => sanitize_text_field( $source_social_stream_name ),
								'social_stream_settings' => serialize( $source_social_stream_settings ),
							),
							array(
								'%s',
								'%s',
								'%s',
							)
						);
						$insert_id = $wpdb->insert_id;
						if ( $insert_id > 0 ) {
							$redirect_link = admin_url( 'admin.php?page=add_shortcode&action=edit&id=' . $insert_id );
							wp_safe_redirect( add_query_arg( 'duplicate', 'true', admin_url( 'admin.php?page=social-stream-designer-add-layouts&action=edit&id=' . $insert_id ) ) );
							exit();
						}
					}
				}
			}
		}
	}
	/**
	 * Enqueue script and style at front side
	 *
	 * @return void
	 */
	public function ssd_front_end_script_style() {
		wp_enqueue_style( 'effects', SOCIALSTREAMDESIGNER_URL . '/css/effects.css', array(), '1.0', false );
		wp_enqueue_style( 'wp-jquery-ui-dialog' );
		wp_enqueue_style( 'ssd_fontawesome', SOCIALSTREAMDESIGNER_URL . '/css/fontawesome-all.min.css', array(), '1.0', false );
		wp_enqueue_style( 'stream-font-family', 'https://fonts.googleapis.com/css?family=Roboto:400,400i,500,700', array(), '1.0', false );
		wp_enqueue_style( 'slickslider', SOCIALSTREAMDESIGNER_URL . '/css/slick.min.css', array(), '1.0', false );
		wp_enqueue_style( 'ssd_justify', SOCIALSTREAMDESIGNER_URL . '/css/justifiedGallery.min.css', array(), '1.0', false );
		wp_enqueue_style( 'stream', SOCIALSTREAMDESIGNER_URL . '/css/style.css', array(), '1.0', false );
		if( is_rtl() ) {
			wp_enqueue_style( 'stream-rtl', SOCIALSTREAMDESIGNER_URL . '/css/style-rtl.css', array(), '1.0', false );
		}
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'isotop', SOCIALSTREAMDESIGNER_URL . '/js/isotope.pkgd.min.js', array( 'jquery' ), '1.0', false );
		wp_enqueue_script( 'ssd_modernizr_custom', SOCIALSTREAMDESIGNER_URL . '/js/modernizr.custom.js', array( 'jquery' ), '1.0', false );
		wp_enqueue_script( 'imagesloaded', SOCIALSTREAMDESIGNER_URL . '/js/imagesloaded.pkgd.min.js', array( 'jquery' ), '1.0', false );
		wp_enqueue_script( 'jquery-masonry' );
		wp_enqueue_script( 'jquery-ui-dialog' );
		wp_enqueue_script( 'ssd_classie', SOCIALSTREAMDESIGNER_URL . '/js/classie.min.js', array( 'jquery' ), '1.0', false );
		wp_enqueue_script( 'slickslider', SOCIALSTREAMDESIGNER_URL . '/js/slick.min.js', array( 'jquery' ), '1.0', false );
		wp_enqueue_script( 'anim-on-scroll', SOCIALSTREAMDESIGNER_URL . '/js/AnimOnScroll.js', array( 'jquery', 'jquery-masonry' ), '1.0', false );
		wp_localize_script(
			'anim-on-scroll',
			'ssdanimobj',
			array(
				'is_rtl'                      => ( is_rtl() ) ? true : false,
			)
		);
		wp_enqueue_script( 'ssd_justify', SOCIALSTREAMDESIGNER_URL . '/js/jquery.justifiedGallery.min.js', array( 'jquery' ), '1.0', false );
		wp_enqueue_script( 'script', SOCIALSTREAMDESIGNER_URL . '/js/script.js', array( 'jquery', 'slickslider' ), '1.0', false );
		wp_localize_script( 'script', 'ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
	}
	/**
	 * Ajax function to update feed on status change
	 *
	 * @return void
	 */
	public function ssd_update_status_feeds() {
		$ssd_nonce = isset( $_POST['ssd_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['ssd_nonce'] ) ) : '';
		if ( wp_verify_nonce( $ssd_nonce, 'ssd_nonce_ajax' ) ) {
			if ( isset( $_POST['action'] ) && 'ssd_update_feed_status' === $_POST['action'] ) {
				global $wpdb;
				$feed_id                       = isset( $_POST['feed_id'] ) ? intval( $_POST['feed_id'] ) : '';
				$feed_status                   = isset( $_POST['feed_status'] ) ? sanitize_text_field( wp_unslash( $_POST['feed_status'] ) ) : '';
				$feed_table_name               = $wpdb->prefix . 'ssd_feeds';
				$read_feed                     = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
				$feeds_settings                = maybe_unserialize( $read_feed->feeds_settings );
				$feeds_settings['feed_status'] = $feed_status;
				$updated_feed_settings         = serialize( $feeds_settings );
				$wpdb->update(
					$wpdb->prefix . 'ssd_feeds',
					array(
						'feeds_settings' => $updated_feed_settings,
					),
					array( 'id' => $feed_id ),
					array(
						'%s',
					),
					array( '%d' )
				);
			}
		}
		wp_die();
	}
	/**
	 * Ajax function to update feed on live status change
	 *
	 * @return void
	 */
	public function ssd_update_live_status_feeds() {
		$ssd_nonce = isset( $_POST['ssd_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['ssd_nonce'] ) ) : '';
		if ( wp_verify_nonce( $ssd_nonce, 'ssd_nonce_ajax' ) ) {
			if ( isset( $_POST['action'] ) && 'ssd_update_feed_live_status' === $_POST['action'] ) {
				global $wpdb;
				$feed_id                            = isset( $_POST['feed_id'] ) ? intval( $_POST['feed_id'] ) : '';
				$feed_live_status                   = isset( $_POST['feed_status_live'] ) ? sanitize_text_field( wp_unslash( $_POST['feed_status_live'] ) ) : '';
				$feed_table_name                    = $wpdb->prefix . 'ssd_feeds';
				$read_feed                          = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
				$feeds_settings                     = maybe_unserialize( $read_feed->feeds_settings );
				$feeds_settings['feed_status_live'] = $feed_live_status;
				$updated_feed_settings              = maybe_serialize( $feeds_settings );
				$wpdb->update(
					$feed_table_name,
					array(
						'feeds_settings' => $updated_feed_settings,
					),
					array( 'id' => $feed_id ),
					array(
						'%s',
					),
					array( '%d' )
				);
			}
		}
		wp_die();
	}
	/**
	 * Get all feeds
	 *
	 * @return void
	 */
	public function ssd_read_all_feed_for_refresh() {
		global $wpdb;
		$get_results = $wpdb->get_results( "SELECT * FROM $wpdb->prefix" . 'ssd_feeds' );
		foreach ( $get_results as $response ) {
			$feeds_settings        = maybe_unserialize( $response->feeds_settings );
			$feeds_type            = $feeds_settings['feed'];
			$feed_type_txt         = explode( '-', $feeds_type );
			$feed_type_text        = $feed_type_txt[0];
			$feed_numbers          = ( isset( $feeds_settings['refresh_feed_on_number'] ) ) ? $feeds_settings['refresh_feed_on_number'] : '';
			$feeds_refresh_dd      = ( isset( $feeds_settings['refresh_feed_on_dd'] ) ) ? $feeds_settings['refresh_feed_on_dd'] : '';
			$last_refresh_time     = ( isset( $response->refresh_feed_date ) ) ? $response->refresh_feed_date : '';
			$updated_referesh_time = gmdate( 'Y-m-d H:i:s', strtotime( '+' . $feed_numbers . $feeds_refresh_dd, strtotime( $last_refresh_time ) ) );
			$current_time          = gmdate( 'Y-m-d H:i:s' );
			if ( $current_time >= $updated_referesh_time ) {
				?>
				<script>
				jQuery(document).ready(function(){
					var ajaxurl = '<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>';
					var ajaxData = {
						'action': 'ssd_action_check_for_refresh_feed',
						'feed_id': '<?php echo intval( $response->id ); ?>',
						'feeds_type': '<?php echo esc_html( $feed_type_text ); ?>',
						'ssd_nonce' : '<?php echo esc_attr( wp_create_nonce( 'ssd_nonce_ajax' ) ); ?>'
					}
					jQuery.post(ajaxurl, ajaxData, function(response){

					});
				});
				</script>
				<?php
			}
		}
	}
	/**
	 * Ajax function to refresh feeds
	 *
	 * @return void
	 */
	public function ssd_refresh_feeds() {
		$ssd_nonce = isset( $_POST['ssd_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['ssd_nonce'] ) ) : '';
		if ( wp_verify_nonce( $ssd_nonce, 'ssd_nonce_ajax' ) ) {
			if ( isset( $_POST['action'] ) ) {
				global $wpdb;
				$feed_id          = ( isset( $_POST['feed_id'] ) && '' !== $_POST['feed_id'] ) ? intval( $_POST['feed_id'] ) : '';
				$feed_type        = ( isset( $_POST['feeds_type'] ) && '' !== $_POST['feeds_type'] ) ? sanitize_text_field( wp_unslash( $_POST['feeds_type'] ) ) : '';
				$feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
				$table_name       = $wpdb->prefix . 'ssd_feeds';
				$wpdb->update(
					$table_name,
					array(
						'refresh_feed_date' => gmdate( 'Y-m-d H:i:s' ),
					),
					array( 'id' => $feed_id ),
					array(
						'%s',
					),
					array( '%d' )
				);
				$ssd_feeds_actions = new SSDFeedsActions();
				$ssd_feeds_actions->init();
				$ssd_feeds_actions->feed_id   = $feed_id;
				$ssd_feeds_actions->feed_type = $feed_type;
				$ssd_feeds_actions->ssd_replace_feed_posts();
			}
		}
		wp_die();
	}
	/**
	 * Function to save order in database
	 *
	 * @return void
	 */
	public function ssd_set_order() {
		$ssd_nonce = isset( $_POST['ssd_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['ssd_nonce'] ) ) : '';
		if ( wp_verify_nonce( $ssd_nonce, 'ssd_nonce_ajax' ) ) {
			if ( ! empty( $_REQUEST['order'] ) ) {
				$ssd_social_order = ( isset( $_REQUEST['order'] ) ) ? sanitize_text_field( wp_unslash( $_REQUEST['order'] ) ) : '';
				$shortcode_id     = ( isset( $_REQUEST['shortcode_id'] ) ) ? intval( $_REQUEST['shortcode_id'] ) : 0;
				update_option( 'ssd_social_order_' . $shortcode_id, $ssd_social_order );
			}
			wp_die();
		}
	}
	/**
	 * Ajax function if display social icon.
	 *
	 * @return void
	 */
	public function ssd_corner_icon() {
			$ssd_nonce = isset( $_POST['ssd_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['ssd_nonce'] ) ) : '';
		if ( wp_verify_nonce( $ssd_nonce, 'ssd_nonce_ajax' ) ) {
			if ( ! empty( $_REQUEST['value'] ) ) {
				$ssd_corner_icon = sanitize_text_field( wp_unslash( $_REQUEST['value'] ) );
				if ( 'true' == $ssd_corner_icon ) {
					echo '<option value="left" selected>' . esc_html__( 'Left', 'social-stream-designer' ) . '</option><option value="right">' . esc_html__( 'Right', 'social-stream-designer' ) . '</option>';
				} else {
					echo '<option value="left" selected>' . esc_html__( 'Left', 'social-stream-designer' ) . '</option><option value="right">' . esc_html__( 'Right', 'social-stream-designer' ) . '</option><option value="center">' . esc_html__( 'Center', 'social-stream-designer' ) . '</option>';
				}
			}
		}
		wp_die();
	}
	/**
	 * Ajax function if display author on.
	 *
	 * @return void
	 */
	public function ssd_update_sticky_on() {
		$ssd_nonce = isset( $_POST['ssd_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['ssd_nonce'] ) ) : '';
		if ( wp_verify_nonce( $ssd_nonce, 'ssd_nonce_ajax' ) ) {
			if ( ! empty( $_REQUEST['author'] ) ) {
				$ssd_display_author = sanitize_text_field( wp_unslash( $_REQUEST['author'] ) );
				if ( 'true' == $ssd_display_author ) {
					echo '<option value="author">' . esc_html__( 'Author', 'social-stream-designer' ) . '</option><option value="media" selected>' . esc_html__( 'Media', 'social-stream-designer' ) . '</option>';
				} else {
					echo '<option value="author" disabled>' . esc_html__( 'Author', 'social-stream-designer' ) . '</option><option value="media" selected>' . esc_html__( 'Media', 'social-stream-designer' ) . '</option>';
				}
			}
		}
		wp_die();
	}
	/**
	 * Reset layout to default.
	 *
	 * @return void
	 */
	public function ssd_reset_layout_settings() {
		$ssd_nonce = isset( $_POST['ssd_nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['ssd_nonce'] ) ) : '';
		if ( wp_verify_nonce( $ssd_nonce, 'ssd_nonce_ajax' ) ) {
			if ( current_user_can( 'manage_options' ) ) {
				if ( isset( $_POST['layout_id'] ) && '' !== $_POST['layout_id'] && '0' !== $_POST['layout_id'] ) {
					global $wpdb;
					$shortcode_table      = $wpdb->prefix . 'ssd_shortcodes';
					$result_settings      = $wpdb->get_var( $wpdb->prepare( "SELECT social_stream_settings FROM $wpdb->prefix" . 'ssd_shortcodes WHERE ID = %d', intval( $_POST['layout_id'] ) ) );
					$settings             = unserialize( $result_settings );
					$feed_ids             = $settings['feed_ids'];
					$ssd_stream_page      = $settings['ssd_stream_page'];
					$ssd_card_extra_class = $settings['ssd_card_extra_class'];
					$ssd_settings         = array(
						'feed_ids'                        => $feed_ids,
						'ssd_stream_page'                 => $ssd_stream_page,
						'ssd_card_extra_class'            => $ssd_card_extra_class,
						'ssd_design_layout'               => 'layout-1',
						'ssd_order_by'                    => 'rand',
						'ssd_display_order'               => '0',
						'ssd_display_private_stream'      => '0',
						'ssd_hide_desktop_stream'         => '0',
						'ssd_hide_mobile_stream'          => '0',
						'ssd_display_meta'                => '1',
						'ssd_custom_css'                  => '',
						'ssd_layout'                      => 'listing',
						'ssd_grid_style'                  => 'masonry',
						'ssd_justified_grid_height'       => '200',
						'ssd_slider_direction'            => 'horizontal',
						'ssd_column_type'                 => '3',
						'ssd_column_type_laptop'          => '3',
						'ssd_column_type_rotated_tablet'  => '2',
						'ssd_column_type_tablet'          => '2',
						'ssd_column_type_rotated_mobile'  => '1',
						'ssd_column_type_mobile'          => '1',
						'ssd_column_type_vertical'        => '3',
						'ssd_stream_title'                => '',
						'ssd_heading_color'               => '',
						'ssd_stream_subtitle'             => '',
						'ssd_subheading_color'            => '',
						'ssd_heading_alignment'           => 'center',
						'ssd_slider_width'                => '800',
						'ssd_display_slider_nav'          => '1',
						'ssd_display_slider_playpause'    => '1',
						'ssd_display_autoplay'            => '0',
						'ssd_slider_interval'             => '1000',
						'ssd_slider_speed'                => '1000',
						'ssd_display_share_with'          => '0',
						'ssd_display_filter'              => '0',
						'ssd_theme_color'                 => '#f93d66',
						'ssd_overlay_bg_color'            => '#ffffff',
						'ssd_overlay_padding_top'         => '0',
						'ssd_overlay_padding_bottom'      => '0',
						'ssd_overlay_padding_left'        => '0',
						'ssd_overlay_padding_right'       => '0',
						'ssd_card_border_top_width'       => '0',
						'ssd_card_border_top_type'        => 'solid',
						'ssd_card_border_top_color'       => '',
						'ssd_card_border_bottom_width'    => '0',
						'ssd_card_border_bottom_type'     => 'solid',
						'ssd_card_border_bottom_color'    => '',
						'ssd_card_border_left_width'      => '0',
						'ssd_card_border_left_type'       => 'solid',
						'ssd_card_border_left_color'      => '',
						'ssd_card_border_right_width'     => '0',
						'ssd_card_border_right_type'      => 'solid',
						'ssd_card_border_right_color'     => '',
						'ssd_card_border_radius'          => '5',
						'ssd_card_border_radius_type'     => 'px',
						'ssd_card_background_color'       => '',
						'ssd_card_overlay_bg_color'       => '',
						'ssd_card_box_hoffset'            => '0',
						'ssd_card_box_voffset'            => '0',
						'ssd_card_box_blur'               => '4',
						'ssd_card_box_spread'             => '0',
						'ssd_card_box_shadow'             => '#cccccc',
						'ssd_display_social_icon'         => '1',
						'ssd_social_share_type'           => 'text',
						'ssd_display_image'               => '0',
						'ssd_image_layout'                => 'ssd_image_layout_1',
						'ssd_display_corner_icon'         => '0',
						'ssd_display_sticky'              => '1',
						'ssd_display_sticky_on'           => 'media',
						'ssd_icon_border_radius'          => '0',
						'ssd_icon_border_radius_type'     => '%',
						'ssd_text_border_radius'          => '0',
						'ssd_text_border_radius_type'     => 'px',
						'ssd_icon_alignment'              => 'left',
						'ssd_icon_position'               => 'top',
						'ssd_icon_color'                  => '',
						'ssd_icon_bg_color'               => '',
						'ssd_display_title'               => '1',
						'ssd_title_font_size'             => '16',
						'ssd_title_color'                 => '#333333',
						'ssd_title_hover_color'           => '#f93d66',
						'ssd_title_bg_color'              => '',
						'ssd_title_padding_top'           => '20',
						'ssd_title_padding_bottom'        => '20',
						'ssd_title_margin_top'            => '0',
						'ssd_title_margin_bottom'         => '0',
						'ssd_title_font_weight'           => 'bold',
						'ssd_display_content'             => '1',
						'ssd_content_limit'               => '50',
						'ssd_content_font_size'           => '14',
						'ssd_content_color'               => '#333333',
						'ssd_content_hover_color'         => '#f93d66',
						'ssd_content_bg_color'            => '',
						'ssd_content_padding_top'         => '0',
						'ssd_content_padding_bottom'      => '0',
						'ssd_content_margin_top'          => '10',
						'ssd_content_margin_bottom'       => '15',
						'ssd_display_feed_without_media'  => '1',
						'ssd_display_default_image'       => '0',
						'ssd_default_image_id'            => '',
						'ssd_default_image_src'           => '',
						'ssd_image_margin_top'            => '0',
						'ssd_image_margin_bottom'         => '20',
						'ssd_display_media_slider_arrows' => '0',
						'ssd_display_media_autoplay'      => '0',
						'ssd_media_slider_interval'       => '1000',
						'ssd_media_slider_speed'          => '1000',
						'ssd_display_author_box'          => '1',
						'ssd_author_border_radius'        => '0',
						'ssd_author_border_radius_type'   => 'px',
						'ssd_author_margin_top'           => '0',
						'ssd_author_margin_bottom'        => '20',
						'ssd_author_padding_top'          => '0',
						'ssd_author_padding_bottom'       => '0',
						'ssd_author_bg_color'             => '',
						'ssd_author_title_color'          => '#f93d66',
						'ssd_author_title_hover_color'    => '#333333',
						'ssd_author_meta_color'           => '#666666',
						'ssd_view_user_name'              => '1',
						'ssd_view_date'                   => '1',
						'ssd_count_meta_color'            => '#666666',
						'ssd_count_bg_color'              => '',
						'ssd_count_meta_hover_color'      => '#f93d66',
						'ssd_count_border_top_width'      => '1',
						'ssd_count_border_top_type'       => 'solid',
						'ssd_count_border_top_color'      => '#e5e5e5',
						'ssd_count_border_bottom_width'   => '0',
						'ssd_count_border_bottom_type'    => 'solid',
						'ssd_count_border_bottom_color'   => '',
						'ssd_count_border_right_width'    => '0',
						'ssd_count_border_right_type'     => 'solid',
						'ssd_count_border_right_color'    => '',
						'ssd_count_border_left_width'     => '0',
						'ssd_count_border_left_type'      => 'solid',
						'ssd_count_border_left_color'     => '#e5e5e5',
						'ssd_count_padding_top'           => '10',
						'ssd_count_padding_bottom'        => '10',
						'ssd_count_margin_top'            => '0',
						'ssd_count_margin_bottom'         => '10',
						'ssd_user_follower_count'         => '1',
						'ssd_user_friend_count'           => '1',
						'ssd_retweet_count'               => '1',
						'ssd_reply_link'                  => '1',
						'ssd_favorite_count'              => '1',
						'ssd_view_count'                  => '1',
						'ssd_like_count'                  => '1',
						'ssd_pin_count'                   => '1',
						'ssd_dislike_count'               => '1',
						'ssd_comment_count'               => '1',
						'ssd_pagination_type'             => 'no_pagination',
						'ssd_pagination_layout'           => 'template-1',
						'ssd_load_more_layout'            => 'template-1',
						'ssd_load_more_effect'            => 'eff-fadein',
						'ssd_no_of_posts_per_page'        => '9',
						'ssd_no_of_posts'                 => '20',
						'ssd_popup_view_on_content_click' => '0',
						'ssd_popup_layout'                => 'layout-1',
					);
					$wpdb->update(
						$shortcode_table,
						array( 'social_stream_settings' => serialize( $ssd_settings ) ),
						array( 'ID' => intval( $_POST['layout_id'] ) ),
						array( '%s' ),
						array( '%d' )
					);
					echo 'success';
				}
			}
		}
		wp_die();
	}

	/**
	 * Add Search
	 */
	public function ssd_search_data() {
		ob_start();
		$layout_object = new SSDLayoutsActions();
		$layout_object->init();
		$shortcode_id = '';
		$ssd_search   = '';
		if ( isset( $_POST['ssd_id'] ) ) {
			$shortcode_id = sanitize_text_field( wp_unslash( $_POST['ssd_id'] ) );
		}
		if ( isset( $_POST['search_val'] ) ) {
			$ssd_search = sanitize_text_field( wp_unslash( $_POST['search_val'] ) );
		}
		$layout_object->id      = $shortcode_id;
		$layout_settings        = $layout_object->ssd_get_layout_detail();
		$shortcode_name         = ( isset( $layout_settings->shortcode_name ) && $layout_settings->shortcode_name != '' ) ? $layout_settings->shortcode_name : '';
		$social_stream_settings = unserialize( $layout_settings->social_stream_settings );
		if ( ! $layout_settings ) {
			return '<b style="color:#ff0000">' . __( 'Error', 'social-stream-designer' ) . ' : </b>' . __( 'Social Stream Feeds shortcode not found. Please cross check your Social Stream Feeds ID.', 'social-stream-designer' );
		}
		// Get feed ids to get feed posts
		$feed_ids     = $social_stream_settings['feed_ids'];
		$feed_ids     = array_values( $feed_ids );
		$feed_ids     = implode( ',', $feed_ids );
		$feeds_object = new SSDFrontFeeds();
		$feeds_object->init();
		$feeds_object->feed_id          = $feed_ids;
		$order                          = isset( $social_stream_settings['ssd_display_order'] ) ? $social_stream_settings['ssd_display_order'] : 0;
		$order_by                       = isset( $social_stream_settings['ssd_order_by'] ) ? $social_stream_settings['ssd_order_by'] : 'date';
		$ssd_display_filter             = isset( $social_stream_settings['ssd_display_filter'] ) ? $social_stream_settings['ssd_display_filter'] : 0;
		$ssd_display_feed_without_media = isset( $social_stream_settings['ssd_display_feed_without_media'] ) ? $social_stream_settings['ssd_display_feed_without_media'] : 1;
		$layout                         = isset( $social_stream_settings['ssd_layout'] ) ? $social_stream_settings['ssd_layout'] : 'listing';
		$pagination_type                = 'no_pagination';
		if ( 'listing' === $layout ) {
			$pagination_type = isset( $social_stream_settings['ssd_pagination_type'] ) ? $social_stream_settings['ssd_pagination_type'] : 'no_pagination';
		}
		$ssd_feed_types	= array('image','video','carousel');

		$ssd_feed_types                    = ( isset( $social_stream_settings['feed_types'] ) && '' !== $social_stream_settings['feed_types'] ) ? $social_stream_settings['feed_types'] : $ssd_feed_types;
		$no_of_posts_per_page  = ( isset( $social_stream_settings['ssd_no_of_posts_per_page'] ) && $social_stream_settings['ssd_no_of_posts_per_page'] > 1 ) ? $social_stream_settings['ssd_no_of_posts_per_page'] : 6;
		$total_number_of_posts = ( isset( $social_stream_settings['ssd_no_of_posts'] ) && $social_stream_settings['ssd_no_of_posts'] > 1 ) ? $social_stream_settings['ssd_no_of_posts'] : '-1';
		if ( 1 == $ssd_display_feed_without_media ) {
			$ssd_total_stream = $feeds_object->ssd_total_stream();
		} else {
			$ssd_total_stream = $feeds_object->ssd_total_stream_without_image();
		}
		if ( '-1' == $total_number_of_posts ) {
			$feeds_object->posts_per_page = 1000;
		} else {
			$feeds_object->posts_per_page = $total_number_of_posts;
		}
		$feeds_object->ssd_display_order              = $order;
		$feeds_object->ssd_order_by                   = $order_by;
		$feeds_object->ssd_display_feed_without_media = $ssd_display_feed_without_media;
		$feeds_object->ssd_search                     = $ssd_search;
		$feeds_object->ssd_feed_types                     = $ssd_feed_types;
		$social_stream                                = $feeds_object->ssd_get_stream();

		if ( is_array( $social_stream ) && ! empty( $social_stream ) ) {
			foreach ( $social_stream as $feeds ) {
				$image = isset( $feeds->post_image ) ? $feeds->post_image : '';
				$video = isset( $feeds->post_video ) ? $feeds->post_video : '';
				if ( 1 == $ssd_display_feed_without_media ) {
					include 'include/social-stream-layout.php';
				} else {
					if ( '' !== $image || '' !== $video ) {
						include 'include/social-stream-layout.php';
					}
				}
			}
		}
		$data = ob_get_clean();
		echo $data;
		die();
	}
	/**
	 * Add Facobool album images on popup
	 */
	public function ssd_facebook_album(){
		ob_start();
		if ( isset( $_POST['feed_type'] ) && isset( $_POST['feed_stream_type'] ) && isset( $_POST['feed_id'] ) ) {
			$feed_type = sanitize_text_field( wp_unslash( $_POST['feed_type'] ) );
			$feed_stream_type = sanitize_text_field( wp_unslash( $_POST['feed_stream_type'] ) );
			$feed_id = sanitize_text_field( wp_unslash( $_POST['feed_id'] ) );
			$ssd_layout = sanitize_text_field( wp_unslash( $_POST['ssd_layout'] ) );
			$ssdid = '';
			if(isset($_POST['ssdid'])){$ssdid = $_POST['ssdid'];}
			if( 'facebook' === $feed_type && 'all_album' === $feed_stream_type ){
				$facebook_stream    = get_option( 'facebook_stream' );
				$fb_accesstoken     = $facebook_stream['facebook_access_token'];
				$url       = 'https://graph.facebook.com/v7.0/'.$feed_id.'?fields=photos{id,images,link,name,from,created_time}&access_token=' . $fb_accesstoken;
				$get_feeds = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
				$posts = json_decode( $get_feeds, true );

				echo '<pre>';
				print_r($posts);
				echo '</pre>';

				$post_data      = isset( $posts['photos']['data'] ) ? $posts['photos']['data'] : array();
				if( !empty($post_data) ){
					$i = 0;
					echo '<div class="ssd-fb-alms">';
					foreach( $post_data as $photo) {
						if( !empty($photo['images'][0]['source']) ){
							$i++;
							$source = $photo['images'][0]['source'];
							$link = $photo['link'];
							$id = $photo['id'];
							$time_ar                        = explode( 'T', $photo['created_time'] );
							$date_time = $time_ar[0];
							$date_time            = human_time_diff( strtotime( $date_time ), current_time( 'timestamp' ) ) . ' ago';
							if(isset($photo['name'])){
								$name = $photo['name'];
							}
							if(isset($photo['from']['name'])){
								$username = $photo['from']['name'];
							}
							$class ='';
							if(!empty($ssdid) && $id == $ssdid ) { $class='ssd-active';}
							echo '<div class="ssd-fb-alm-image ssd-fb-alm-image'.$i .' '.$class.' " data-dialog="'.$i.'" data-id="'.$id.'" data-feed_id="'.$feed_id.'" data-layout="'.$ssd_layout.'" data-content="'.$name.'" data-username="'.$username.'" data-image="'.$source.'" data-userscreenname="@'.$username.'" data-datetime="'.$date_time.'" data-link="'.$link.'" data-fancybox="gallery"><img src="'.$source.'"></div>';
						}
					}
					echo '</div>';
				}
			}
		}
		$o = ob_get_clean();
		echo $o;
		die();
	}

	/** 
	 * inclue auto-update file.
	 */
	public function ssd_include_autoupdate() {
		include_once 'admin/assets/wp_autoupdate.php';
		new ssd_wp_auto_update();
	}
	/**
	 * Add Facobool comments display on popup
	 */
	public function ssd_display_comments_popup(){
		ob_start();
		if(isset($_POST['feed_type']) && !empty($_POST['feed_type']) ){
			$feed_type = sanitize_text_field( wp_unslash( $_POST['feed_type'] ) );
			$ssd_cmt_id = '';
			$ssd_username = '';
			$ssd_cmt_cnt = '';
			$ssd_cmt_link = '';
			if(isset($_POST['ssdcommentid']) && !empty($_POST['ssdcommentid']) ){
				$ssd_cmt_id = sanitize_text_field( wp_unslash( $_POST['ssdcommentid'] ) );
			}
			if(isset($_POST['username']) && !empty($_POST['username']) ){
				$ssd_username = sanitize_text_field( wp_unslash( $_POST['username'] ) );
			}
			if(isset($_POST['ssd_cmt_cnt']) && !empty($_POST['ssd_cmt_cnt']) ){
				$ssd_cmt_cnt = sanitize_text_field( wp_unslash( $_POST['ssd_cmt_cnt'] ) );
			}
			if(isset($_POST['ssd_cmt_link']) && !empty($_POST['ssd_cmt_link']) ){
				$ssd_cmt_link = sanitize_text_field( wp_unslash( $_POST['ssd_cmt_link'] ) );
			}
			if( 'facebook' === $feed_type && !empty($ssd_cmt_id) ) {
				$facebook_stream    = get_option( 'facebook_stream' );
				$fb_accesstoken     = $facebook_stream['facebook_access_token'];
				$url       = 'https://graph.facebook.com/'.$ssd_cmt_id.'/comments?fields=id,from,message,comments{created_time,from,id,message,message_tags,attachment,like_count},created_time,message_tags,attachment,like_count,comment_count&access_token=' . $fb_accesstoken;
				$get_feeds = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
				$posts = json_decode( $get_feeds, true );
				$post_data      = isset( $posts['data'] ) ? $posts['data'] : array();
				if ( ! empty( $post_data ) ) {
					echo '<div class="ssd-pop-comments-wrap">';
					foreach ( $post_data as $post ) {
						echo '<div class="ssd-pop-comments-data">';
						if(isset($post['message']) && !empty($post['message'])){
							$date_time            = human_time_diff( strtotime( $post['created_time'] ), current_time( 'timestamp' ) ) . ' ago';
							if(isset($post['from']['id']) ) {
								$user_id = $post['from']['id'];
								echo '<div class="ssd-comment-user"><img src="https://graph.facebook.com/'.$user_id.'/picture?access_token='.$fb_accesstoken.'" width="20" height="20"></div>';
								echo '<div class="ssd-comment-user-msg"><p class="ssd-cmt-user"><a href="http://facebook.com/'.$user_id.'" target="_blank">'.$post['from']['name'].'</a></p><p class="ssd-cmt-msg">'.$post['message'].'</p><span class="ssd-cmt-date">'.$date_time.'</span></div>'; 
							} else {
								echo '<div class="ssd-comment-msg"><p class="ssd-cmt-msg">'.$post['message'].'</p><span class="ssd-cmt-date">'.$date_time.'</span></div>';
							}
						}
						if(isset($post['comment_count']) && $post['comment_count'] > 0 ) {
							echo '<p class="ssd-comment-replies"><a class="ssd-comment-replies-a" href="javascript:void(0);"><span class="ssd-replies-icon"><i class="fas fa-share"></i></span>'.$post['comment_count'].' '.esc_html__( 'Replies', 'social-stream-designer' ).'</a></p>';
						}
						if(isset($post['comments']['data']) && !empty($post['comments']['data'])){
							echo '<div class="ssd-comments-replies-box" style="display: none;">';
							foreach($post['comments']['data'] as $comments){
								echo '<div class="ssd-cmt-rep-data">';
								if(isset($comments['from']['id']) ) {
									$comments_id = $comments['from']['id'];
									echo '<div class="ssd-comment-user"><img src="https://graph.facebook.com/'.$comments_id.'/picture?access_token='.$fb_accesstoken.'" width="20" height="20"></div>';
									echo '<div class="ssd-comment-user-msg"><p class="ssd-cmt-user"><a href="http://facebook.com/'.$comments_id.'" target="_blank">'.$comments['from']['name'].'</a></p><p class="ssd-cmt-msg">'.$comments['message'].'</p></div>';
								} else {
									echo '<div class="ssd-comment-msg"><p class="ssd-cmt-msg">'.$comments['message'].'</p></div>';
								}
								echo '</div>';
							}
							echo '</div>';
						}
						echo '</div>';
					}
					if(!empty($ssd_cmt_cnt) && $ssd_cmt_cnt > 20 ) {
						echo '<div class="ssd-all-cmt-btn"><a href="'.$ssd_cmt_link.'" target="_blank">'.esc_html__('View all comments','social-stream-designer').'</a></div>';
					}
					echo '</div>';
				}
			}
			if( 'flickr' === $feed_type && !empty($ssd_cmt_id) ) {
				$flickr_stream    = get_option( 'flickr_stream' );
				include_once SOCIALSTREAMDESIGNER_DIR . '/include/phpFlickr.php';
				$api_key    = $flickr_stream['api_key'];
				$api_secret = $flickr_stream['api_secret'];
				$flickr_obj = new phpFlickr( $api_key, $api_secret, true );
				$result = $flickr_obj->call("flickr.photos.comments.getList", array("photo_id"=>$ssd_cmt_id));
				if ( ! empty( $result ) ) {
					echo '<div class="ssd-pop-comments-wrap">';
					foreach ( $result as $result_data ) {
						if(isset($result_data['comment']) && !empty($result_data['comment'])){
							foreach($result_data['comment'] as $comments){
								$datecreate = gmdate( 'Y-m-d h:i:s', $comments['datecreate'] );
								$date_time            = human_time_diff( strtotime( $datecreate ), current_time( 'timestamp' ) ) . ' ago';
								$nsid = $comments['author'];
								$authorname = $comments['authorname'];
								$iconserver = $comments['iconserver'];
								$iconfarm = $comments['iconfarm'];
								$content = $comments['_content'];
								$aut_photo = 'http://farm'.$iconfarm .'.staticflickr.com/'.$iconserver.'/buddyicons/'.$nsid.'.jpg';
								echo '<div class="ssd-pop-comments-data">';
								echo '<div class="ssd-comment-user"><img src="'.$aut_photo.'" width="20" height="20"></div>';
								echo '<div class="ssd-comment-user-msg"><p class="ssd-cmt-user"><a href="https://www.flickr.com/'.$nsid.'" target="_blank">'.$authorname.'</a></p><p class="ssd-cmt-msg">'.$content.'</p><span class="ssd-cmt-date">'.$date_time.'</span></div>';
								echo '</div>';
							}
						}
					}
					if(!empty($ssd_cmt_cnt) && $ssd_cmt_cnt > 20 ) {
						echo '<div class="ssd-all-cmt-btn"><a href="'.$ssd_cmt_link.'" target="_blank">'.esc_html__('View all comments','social-stream-designer').'</a></div>';
					}
					echo '</div>';
				}
			}
			if( 'soundcloud' === $feed_type && !empty($ssd_cmt_id) ) {
				$soundcloud_stream = get_option( 'soundcloud_stream' );
				$access_token      = $soundcloud_stream['soundcloud_access_token'];
				$soundcloud_url = 'http://api.soundcloud.com/tracks/'.$ssd_cmt_id.'/comments.json?limit=20&client_id=' . $access_token;
				$comment_json    = Social_Stream_Main::ssd_get_data_from_remote_url( $soundcloud_url );
				$result         = json_decode( $comment_json,true );
				if ( ! empty( $result ) ) {
					echo '<div class="ssd-pop-comments-wrap">';
					foreach ( $result as $result_data ) {
						echo '<div class="ssd-pop-comments-data">';
						$message = $result_data['body'];
						$created_date = $result_data['created_at'];
						$user_name = $result_data['user']['username'];
						$permalink_url = $result_data['user']['permalink_url'];
						$avatar_url = $result_data['user']['avatar_url'];
						$date_time  = human_time_diff( strtotime( $created_date ), current_time( 'timestamp' ) ) . ' ago';
						if(!empty($avatar_url)) {
							echo '<div class="ssd-comment-user"><img src="'.$avatar_url.'" width="20" height="20"></div>';
						}
						echo '<div class="ssd-comment-user-msg"><p class="ssd-cmt-user"><a href="'.$permalink_url.'" target="_blank">'.$user_name.'</a></p><p class="ssd-cmt-msg">'.$message.'</p><span class="ssd-cmt-date">'.$date_time.'</span></div>';
						echo '</div>';
					}
					if(!empty($ssd_cmt_cnt) && $ssd_cmt_cnt > 20 ) {
						echo '<div class="ssd-all-cmt-btn"><a href="'.$ssd_cmt_link.'" target="_blank">'.esc_html__('View all comments','social-stream-designer').'</a></div>';
					}
					echo '</div>';
				}
			}
			if( 'tumblr' === $feed_type && !empty($ssd_cmt_id) ) {
				$tumblr_stream             = get_option( 'tumblr_stream' );
				$consumer_key              = $tumblr_stream['consumer_key'];
				$url             = 'https://api.tumblr.com/v2/blog/' . $ssd_username . '.tumblr.com/posts?id='.$ssd_cmt_id.'&api_key=' . $consumer_key . '&notes_info=true' ;
				$read_feed       = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
				$get_tumblr_feed = json_decode( $read_feed );
				$feed_posts            = isset( $get_tumblr_feed->response->posts ) ? $get_tumblr_feed->response->posts : '';
				if ( ! empty( $feed_posts ) ) {
					foreach ( $feed_posts as $feed ) {
						$tumblr_notes = $feed->notes;
						if(!empty($tumblr_notes)){
							echo '<div class="ssd-pop-comments-wrap">';
							foreach ( $tumblr_notes as $note ) {
								if(isset($note->reply_text) && !empty($note->reply_text)){
									echo '<div class="ssd-pop-comments-data">';
									$message = $note->reply_text;
									$created_date = $note->timestamp;
									$datecreate = gmdate( 'Y-m-d h:i:s', $created_date );
									$user_name = $note->blog_name;
									$permalink_url = $note->blog_url;
									$avatar_url = 'https://api.tumblr.com/v2/blog/' . $user_name . '.tumblr.com/avatar/24';
									$datetime = human_time_diff( strtotime( $datecreate ), current_time( 'timestamp' ) ) . ' ago';
									if(!empty($avatar_url)) {
										echo '<div class="ssd-comment-user"><img src="'.$avatar_url.'" width="20" height="20"></div>';
									}
									echo '<div class="ssd-comment-user-msg"><p class="ssd-cmt-user"><a href="'.$permalink_url.'" target="_blank">'.$user_name.'</a></p><p class="ssd-cmt-msg">'.$message.'</p><span class="ssd-cmt-date">'.$datetime.'</span></div>';
									echo '</div>';
								}
							}
							if(!empty($ssd_cmt_cnt) && $ssd_cmt_cnt > 20 ) {
								echo '<div class="ssd-all-cmt-btn"><a href="'.$ssd_cmt_link.'" target="_blank">'.esc_html__('View all comments','social-stream-designer').'</a></div>';
							}
							echo '</div>';
						}
					}
				}
			}
			if( 'vimeo' === $feed_type && !empty($ssd_cmt_id) ) {
				$vimeo_stream      = get_option( 'vimeo_stream' );
				$vimeo_client_id   = $vimeo_stream['client_id'] ? $vimeo_stream['client_id'] : '';
				$vimeo_secrets_key = $vimeo_stream['secrets_key'] ? $vimeo_stream['secrets_key'] : '';
				include_once SOCIALSTREAMDESIGNER_DIR . 'include/vimeoPhp/autoload.php';
				$lib   = new \Vimeo\Vimeo( $vimeo_client_id, $vimeo_secrets_key );
				$response = $lib->request( '/videos/'.$ssd_cmt_id.'/comments?per_page=20', '', 'GET' );
				$feed_posts = isset( $response['body']['data'] ) ? $response['body']['data'] : '';
				if ( ! empty( $feed_posts ) ) {
					echo '<div class="ssd-pop-comments-wrap">';
					foreach ( $feed_posts as $result_data ) {
						$message = $result_data['text'];
						$datetime = human_time_diff( strtotime( $result_data['created_on'] ), current_time( 'timestamp' ) ) . ' ago';
						$user_name = $result_data['user']['name'];
						$permalink_url = $result_data['user']['link'];
						$avatar_url = isset( $result_data['user']['pictures']['sizes'][0]['link'] ) ? $result_data['user']['pictures']['sizes'][0]['link'] : '';
						echo '<div class="ssd-pop-comments-data">';
						if(!empty($avatar_url)) {
							echo '<div class="ssd-comment-user"><img src="'.$avatar_url.'" width="20" height="20"></div>';
						}
						echo '<div class="ssd-comment-user-msg"><p class="ssd-cmt-user"><a href="'.$permalink_url.'" target="_blank">'.$user_name.'</a></p><p class="ssd-cmt-msg">'.$message.'</p><span class="ssd-cmt-date">'.$datetime.'</span></div>';
						echo '</div>';
					}
					if(!empty($ssd_cmt_cnt) && $ssd_cmt_cnt > 20 ) {
						echo '<div class="ssd-all-cmt-btn"><a href="'.$ssd_cmt_link.'" target="_blank">'.esc_html__('View all comments','social-stream-designer').'</a></div>';
					}
					echo '</div>';
				}
			}
			if( 'youtube' === $feed_type && !empty($ssd_cmt_id) ) {
				$youtube_stream    = get_option( 'youtube_stream' );
				$youtube_api_key   = $youtube_stream['youtube_key'];
				$get_video_url = 'https://www.googleapis.com/youtube/v3/commentThreads?textFormat=plainText&part=id,snippet,replies&videoId=' . $ssd_cmt_id . '&max_results=20&key=' . $youtube_api_key;
				$read_feed     = Social_Stream_Main::ssd_get_data_from_remote_url( $get_video_url );
				$video_data    = json_decode( $read_feed );
				$videos_data_items = isset( $video_data->items ) ? $video_data->items : '';
				if ( ! empty( $videos_data_items ) ) {
					echo '<div class="ssd-pop-comments-wrap">';
					foreach ( $videos_data_items as $result_data ) {
						$message = $result_data->snippet->topLevelComment->snippet->textDisplay;
						$publishedAt = $result_data->snippet->topLevelComment->snippet->publishedAt;
						$user_name = $result_data->snippet->topLevelComment->snippet->authorDisplayName;
						$avatar_url = isset( $result_data->snippet->topLevelComment->snippet->authorProfileImageUrl ) ? $result_data->snippet->topLevelComment->snippet->authorProfileImageUrl : '';
						$permalink_url ='https://www.youtube.com/channel/' . $result_data->snippet->topLevelComment->snippet->authorChannelId->value;
						$datetime = human_time_diff( strtotime( $publishedAt ), current_time( 'timestamp' ) ) . ' ago';
						$comment_count = $result_data->snippet->totalReplyCount;
						$comment_replies = isset($result_data->replies->comments) ? $result_data->replies->comments : '';
						echo '<div class="ssd-pop-comments-data">';
						if(!empty($avatar_url)) {
							echo '<div class="ssd-comment-user"><img src="'.$avatar_url.'" width="20" height="20"></div>';
						}
						echo '<div class="ssd-comment-user-msg"><p class="ssd-cmt-user"><a href="'.$permalink_url.'" target="_blank">'.$user_name.'</a></p><p class="ssd-cmt-msg">'.$message.'</p><span class="ssd-cmt-date">'.$datetime.'</span>';
						if(isset($comment_count) && $comment_count > 0 ) {
							echo '<p class="ssd-comment-replies"><a class="ssd-comment-replies-a" href="javascript:void(0);"><span class="ssd-replies-icon"><i class="fas fa-share"></i></span>'.$comment_count.' '.esc_html__( 'Replies', 'social-stream-designer' ).'</a></p>';
						}
						if(isset($comment_replies) && !empty($comment_replies)){
							echo '<div class="ssd-comments-replies-box" style="display: none;">';
							foreach($comment_replies as $comments){
								$message = $comments->snippet->textDisplay;
								$publishedAt = $comments->snippet->publishedAt;
								$user_name = $comments->snippet->authorDisplayName;
								$avatar_url = isset( $comments->snippet->authorProfileImageUrl ) ? $comments->snippet->authorProfileImageUrl : '';
								$permalink_url ='https://www.youtube.com/channel/' . $comments->snippet->authorChannelId->value;
								$datetime = human_time_diff( strtotime( $publishedAt ), current_time( 'timestamp' ) ) . ' ago';
								echo '<div class="ssd-cmt-rep-data">';
								if(!empty($avatar_url)){
									echo '<div class="ssd-comment-user"><img src="'.$avatar_url.'" width="20" height="20"></div>';
								}
								echo '<div class="ssd-comment-user-msg"><p class="ssd-cmt-user"><a href="'.$permalink_url.'" target="_blank">'.$user_name.'</a></p><p class="ssd-cmt-msg">'.$message.'</p></div>';
								
								echo '</div>';
							}
							echo '</div>';
						}
						echo '</div></div>';
					}
					if(!empty($ssd_cmt_cnt) && $ssd_cmt_cnt > 20 ) {
						echo '<div class="ssd-all-cmt-btn"><a href="'.$ssd_cmt_link.'" target="_blank">'.esc_html__('View all comments','social-stream-designer').'</a></div>';
					}
					echo '</div>';
				}
			}
		}
		$o = ob_get_clean();
		echo $o;
		die();
	}

	/**
	 * Ssd fee biography for facebook page
	 */
	public function ssd_feed_bio_details() {
		ob_start();
		$facebook_stream    = get_option( 'facebook_stream' );
		$fb_accesstoken     = $facebook_stream['facebook_access_token'];
		$feed_id = $_POST['feed_id'];
		$ids                            = explode( '_', $feed_id );
		$url       = 'https://graph.facebook.com/v7.0/'.$ids[0].'?fields=about,attire,bio,location,parking,hours,emails,website,description,name&access_token=' . $fb_accesstoken;
		$get_feeds = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
		$posts = json_decode( $get_feeds, true );
		if( !empty ( $posts ) ) {
			echo '<div class="ssd_popup_page_details">'; 
			if( isset( $posts['name'] ) && !empty( $posts['name'] ) ) { echo '<h4>'.$posts["name"].' ' . esc_html__( 'details', 'social-stream-designer' ) .'</h4>'; }
			if( isset( $posts['about'] ) && !empty( $posts['about'] ) ) { echo '<p class="ssd_pup_pd_about"><b>'.esc_html__( 'About', 'social-stream-designer' ).' : </b>'.$posts["about"].'</h4>'; }
			echo '</div>';
			if( isset( $posts['website'] ) && !empty( $posts['website'] ) ) { echo '<p class="ssd_pup_pd_wsite"><b>'.esc_html__( 'Website', 'social-stream-designer' ).' : </b><a href="'.$posts['website'].'">'.$posts["website"].'</a></h4>'; }
			echo '</div>';
		}
		$o = ob_get_clean();
		echo $o;
		die();
	}
	/**
	 * Add support to visual composer plugin
	 *
	 * @return void
	 */
	public function ssd_add_vc_support() {
		global $wpdb;
		$shortcode_table      = $wpdb->prefix . 'ssd_shortcodes';
		$ssd_ids       = $wpdb->get_results( "SELECT ID,shortcode_name FROM $shortcode_table" ); //phpcs:ignore
		$ssd_ipd_array = array( 'Select Layout Id' );
		if ( ! empty( $ssd_ids ) && is_array( $ssd_ids ) ) {
			foreach ( $ssd_ids as $ssd_id ) {
				$ssd_ipd_array[ $ssd_id->shortcode_name ] = $ssd_id->ID;
			}
		}
		vc_map(
			array(
				'name'              => esc_html__( 'Social Stream Designer', 'social-stream-designer' ),
				'base'              => 'social_stream_feeds',
				'class'             => 'social_stream_designer_section',
				'category'          => esc_html__( 'Content' ),
				'icon'              => 'social_stream_designer_icon',
				'admin_enqueue_css' => array( SOCIALSTREAMDESIGNER_DIR . 'admin/css/vc_style.css' ),
				'description'       => esc_html__( 'Custom Feed Layouts', 'social-stream-designer' ),
				'params'            => array(
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Select Layout Id', 'social-stream-designer' ),
						'param_name'  => 'id',
						'value'       => $ssd_ipd_array,
						'admin_label' => true,
					),
				),
			)
		);
	}

	/**
	 * SSD layout export.
	 */
	public function ssd_layout_export() {
		if ( isset( $_GET['action'] ) && $_GET['action'] == 'demoexport' && isset( $_GET['id'] ) && $_GET['id'] != '') {
			global $wpdb;
			$id         = $_GET['id'];
			$table_name = $wpdb->prefix . 'ssd_shortcodes';
			$data       = $wpdb->get_row( "SELECT * FROM $table_name WHERE ID = $id" );
			$output     = base64_encode( serialize( $data ) );
			$name       = str_replace( ' ', '_', $data->shortcode_name );
			$file_name  = $data->ID . '_' . $name . '.txt';
			do_action( 'export_feed_layout', $data->shortcode_name );
			$this->download_stream_layout( $file_name, $output );
			echo $output;
			exit();
		}
	}
	/**
	 * Download Portfolio Layout Fole
	 */
	public function download_stream_layout( $file_name, $output ) {
		header( 'Content-type: application/text', true, 200 );
		header( "Content-Disposition: attachment; filename=$file_name", true );
		header( 'Pragma: no-cache' );
		header( 'Expires: 0' );
		echo $output;
		exit();
	}

	/** 
	 * Import Demo layout
	 */
	public function ssd_layout_demo_import() {
		if ( isset( $_REQUEST['ssd_file_demo_import'] ) && ! empty( $_FILES['ssd_demo_layout_import_file'] ) && check_admin_referer( 'ssd_demo_import', 'ssd_demo_import_nonce' ) ) {
			global $import_success, $wpdb;
			$shortcode_table        = $wpdb->prefix . 'ssd_shortcodes';
			$uploaded_file = $_FILES['ssd_demo_layout_import_file'];
			// Upload file and check uploading error
			$overrides = array( 'test_form' => false );
			$file_data = wp_handle_upload( $uploaded_file, $overrides );
			if ( isset( $file_data['error'] ) ) {
				wp_die(
					$file_data['error'],
					'',
					array( 'back_link' => true )
				);
			}

			// Check file exists or not
			if ( ! file_exists( $file_data['file'] ) ) {
				wp_die(
					__( 'Import file could not be found. Please try again.', 'social-stream-designer' ),
					'',
					array( 'back_link' => true )
				);
			}

			$content = $this->ssd_import_layouts( $file_data['file'] );

			// $content = json_decode($data, true);
		
			if(isset($content->social_stream_settings) && !empty($content->social_stream_settings)) {
				$layout_outputs = $content->social_stream_settings;
				$settings = unserialize( $layout_outputs );
				$settings['feed_ids'] = array();
				$settings['ssd_stream_page'] = '';
				$settings['ssd_default_image_src'] = '';
				$settings['ssd_default_image_id'] = '';
				$wpdb->insert(
					$shortcode_table,
					array(
						'shortcode_name'         => $content->shortcode_name,
						'social_stream_name'     => '',
						'social_stream_settings' => serialize( $settings ),
					),
					array(
						'%s',
						'%s',
						'%s',
					)
				);
			}
			$_SESSION['import_layout'] = 'sucess';
		}
	}

	/**
	 * Check Upload File Contents
	 *
	 * @param file_path $file
	 */
	public function ssd_import_layouts( $file ) {
		if ( file_exists( $file ) ) {
			$file_content = $this->ssd_file_contents( $file );
			if ( $file_content ) {
				if ( base64_decode( $file_content, true ) ) {
					if ( is_serialized( base64_decode( $file_content ) ) ) {
						$unserialized_content = unserialize( base64_decode( $file_content ) );
						if ( $unserialized_content ) {
							return $unserialized_content;
						}
					} else {
						wp_die(
							__( 'Import file is not valid. Please try again.', 'social-stream-designer' ),
							'',
							array( 'back_link' => true )
						);
					}
				} else {
					wp_die(
						__( 'Import file is not valid. Please try again.', 'social-stream-designer' ),
						'',
						array( 'back_link' => true )
					);
				}
			} else {
				wp_die(
					__( 'Import file is empty. Please try again.', 'social-stream-designer' ),
					'',
					array( 'back_link' => true )
				);
			}
		} else {
			wp_die(
				__( 'Import file could not be found. Please try again.', 'social-stream-designer' ),
				'',
				array( 'back_link' => true )
			);
		}
	}
	/**
	 * Get Upload File Contents
	 *
	 * @param $path
	 * @return FileContents
	 */
	public function ssd_file_contents( $path ) {
		$ssd_content = '';
		if ( function_exists( 'realpath' ) ) {
			$filepath = realpath( $path );
		}
		if ( ! $filepath || ! @is_file( $filepath ) ) {
			return;
		}

		if ( ini_get( 'allow_url_fopen' ) ) {
			$ssd_file_method = 'fopen';
		} else {
			$ssd_file_method = 'file_get_contents';
		}

		if ( $ssd_file_method == 'fopen' ) {
			$ssd_handle = fopen( $filepath, 'rb' );

			if ( false != $ssd_handle ) {
				while ( ! feof( $ssd_handle ) ) {
					$ssd_content .= fread( $ssd_handle, 8192 );
				}
				fclose( $ssd_handle );
			}
			return $ssd_content;
		} else {
			return file_get_contents( $filepath );
		}
	}

	/**
	 * Display Admin notice
	 */
	public function general_admin_notice(){
		if ( isset( $_SESSION['import_layout'] ) && 'sucess'== $_SESSION['import_layout'] ) {
			echo '<div class="notice notice-success is-dismissible" style="padding: 10px;">'.__('Layout imported sucessfully.', 'social-stream-designer').'</div>';
			$_SESSION['import_layout'] = '';
		}
	}
}
new SocialStream();
