<?php

/**
 * File to Social stream
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get Twitter stream data
 *
 * @return array
 */
class SSDFrontFeeds {

	/**
	 * Feed Stream
	 *
	 * @var string
	 */
	public $feeds_stream;

	/**
	 * Feed id
	 *
	 * @var string
	 */
	public $feed_id = '';

	/**
	 * Feed post table
	 *
	 * @var string
	 */
	public $feed_posts_table = '';

	/**
	 * Current Page
	 *
	 * @var string
	 */
	public $cur_page = 1;

	/**
	 * Post per page
	 *
	 * @var string
	 */
	public $posts_per_page = 6;

	/**
	 * Max number of posts
	 *
	 * @var string
	 */
	public $max_number_of_posts = '1000';

	/**
	 * Pagination
	 *
	 * @var string
	 */
	public $pagination = '0';

	/**
	 * Initialize .
	 *
	 * @since    1.0.0
	 */
	public function init() {
		global $wpdb;
		$feed_posts_table       = $wpdb->prefix . 'ssd_feed_posts';
		$this->feed_posts_table = $feed_posts_table;
	}

	/**
	 * Get Stream
	 *
	 * @since  1.0.0
	 * @return string
	 */
	public function ssd_get_stream() {
		global $wpdb;
		$feed_posts_table               = $wpdb->prefix . 'ssd_feed_posts';
		$feed_id                        = $this->feed_id;
		$cur_page                       = $this->cur_page;
		$posts_per_page                 = $this->posts_per_page;
		$max_number_of_posts            = $this->max_number_of_posts;
		$ssd_order                      = $this->ssd_display_order;
		$ssd_order_by                   = $this->ssd_order_by;
		$ssd_search                     = $this->ssd_search;
		$ssd_feed_types                 = $this->ssd_feed_types;
		$ssd_order                      = (int) $ssd_order;
		$ssd_display_feed_without_media = $this->ssd_display_feed_without_media;
		$ssd_display_feed_without_media = (int) $ssd_display_feed_without_media;
		if ( 1 == $ssd_order ) {
			$order = 'ASC';
		} else {
			$order = 'DESC';
		}
		if ( 'date' === $ssd_order_by ) {
			$order_by = 'ORDER BY post_date';
		} elseif ( 'social-media' === $ssd_order_by ) {
			$order_by = 'ORDER BY feed_type';
		} else {
			$order_by = 'ORDER BY rand()';
		}
		$display_feed = '';
		if(in_array('carousel',$ssd_feed_types)) {
			array_push($ssd_feed_types, 'carousel_album');
		}
		if(!empty($ssd_feed_types)) {
			$feed_types = implode( "','", $ssd_feed_types );
		}
		$display_feed = " AND type_in IN ( '" .$feed_types ."' )";

		if ( ! empty( $feed_id ) ) {
			if ( '' !== $ssd_search ) {
				if ( 1 == $ssd_display_feed_without_media ) {
					if ( is_user_logged_in() && current_user_can( 'manage_options' ) ) {
						$query = $wpdb->prepare( "SELECT  * FROM $feed_posts_table WHERE feed_id IN ( $feed_id ) $display_feed AND (post_title LIKE %s OR post_description LIKE %s) $order_by $order", '%' . $ssd_search . '%', '%' . $ssd_search . '%' );
					} elseif ( is_user_logged_in() && ! current_user_can( 'manage_options' ) ) {
						$query = $wpdb->prepare( "SELECT  * FROM $feed_posts_table WHERE feed_id IN ( $feed_id ) $display_feed AND (post_title LIKE %s OR post_description LIKE %s) AND (( moderate = '1' AND lower(post_status) = 'yes'))  $order_by $order", '%' . $ssd_search . '%', '%' . $ssd_search . '%' );
					} else {
						$query = $wpdb->prepare( "SELECT  * FROM $feed_posts_table WHERE feed_id IN ( $feed_id ) $display_feed AND (post_title LIKE %s OR post_description LIKE %s) AND (( moderate = '1' AND lower(post_status) = 'yes') OR (moderate IS NULL or moderate ='')) $order_by $order", '%' . $ssd_search . '%', '%' . $ssd_search . '%' );
					}
				} else {
					if ( is_user_logged_in() && current_user_can( 'manage_options' ) ) {
						$query = $wpdb->prepare( "SELECT * FROM $feed_posts_table WHERE feed_id IN ( $feed_id ) $display_feed AND ((type_in = 'video' AND post_video != '') OR (type_in = 'image' AND post_image != '')) AND (post_title LIKE %s OR post_description LIKE %s)  $order_by $order", '%' . $ssd_search . '%', '%' . $ssd_search . '%' );
					} elseif ( is_user_logged_in() && ! current_user_can( 'manage_options' ) ) {
						$query = $wpdb->prepare( "SELECT * FROM $feed_posts_table WHERE feed_id IN ( $feed_id ) $display_feed AND ((type_in = 'video' AND post_video != '') OR (type_in = 'image' AND post_image != '')) AND (post_title LIKE %s OR post_description LIKE %s) AND (( moderate = '1' AND lower(post_status) = 'yes'))  $order_by $order", '%' . $ssd_search . '%', '%' . $ssd_search . '%' );
					} else {
						$query = $wpdb->prepare( "SELECT * FROM $feed_posts_table WHERE feed_id IN ( $feed_id ) $display_feed AND ((type_in = 'video' AND post_video != '') OR (type_in = 'image' AND post_image != '')) AND (post_title LIKE %s OR post_description LIKE %s) AND (( moderate = '1' AND lower(post_status) = 'yes') OR (moderate IS NULL or moderate ='')) $order_by $order", '%' . $ssd_search . '%', '%' . $ssd_search . '%' );
					}
				}
			} else {
				if ( 1 == $ssd_display_feed_without_media ) {
					if ( is_user_logged_in() && current_user_can( 'manage_options' ) ) {
						$query = 'select * from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . ' ) ' . $display_feed .' ' .$order_by . ' ' . $order;
					} elseif ( is_user_logged_in() && ! current_user_can( 'manage_options' ) ) {
						$query = 'select * from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . " ) AND (( moderate = '1' AND lower(post_status) = 'yes')) " . $display_feed .' ' . $order_by . ' ' . $order;
					} else {
						$query = 'select * from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . " ) AND (( moderate = '1' AND lower(post_status) = 'yes') OR (moderate IS NULL or moderate ='')) " . $display_feed .' ' . $order_by . ' ' . $order;
					}
				} else {
					
					if ( is_user_logged_in() && current_user_can( 'manage_options' ) ) {
						$query = 'select * from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . " ) AND ((type_in = 'video' AND post_video != '') OR (type_in = 'image' AND post_image != '')) " . $display_feed .' '. $order_by . ' ' . $order;
					} elseif ( is_user_logged_in() && ! current_user_can( 'manage_options' ) ) {
						$query = 'select * from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . " ) AND ((type_in = 'video' AND post_video != '') OR (type_in = 'image' AND post_image != '')) AND (( moderate = '1' AND lower(post_status) = 'yes')) " . $display_feed .' '. $order_by . ' ' . $order;
					} else {
						$query = 'select * from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . " ) AND ((type_in = 'video' AND post_video != '') OR (type_in = 'image' AND post_image != '')) AND (( moderate = '1' AND lower(post_status) = 'yes') OR (moderate IS NULL or moderate ='')) " . $display_feed .' '. $order_by . ' ' . $order;
					}
				}
			}
			$limit_start = 0;
			if ( '1' !== $this->pagination ) {
				$limit_start = ( $cur_page - 1 ) * ( $posts_per_page );
			}
			$limit_end = $limit_start + $posts_per_page;
			if ( $limit_end > $max_number_of_posts ) {
				$posts_per_page = $posts_per_page - ( $limit_end - $max_number_of_posts );
			}
			$query       .= " limit $limit_start,$posts_per_page";
			// echo $query;
			$feeds_stream = $wpdb->get_results( $query );
			if ( $feeds_stream ) {
				return $feeds_stream;
			} else {
				return esc_html__( 'No feeds found', 'social-stream-designer' );
			}
		}
	}

	/**
	 * Total Stream
	 *
	 * @since  1.0.0
	 * @return string
	 */
	public function ssd_total_stream() {
		global $wpdb;
		$feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		$feed_id          = $this->feed_id;
		if ( is_user_logged_in() ) {
			$query = 'select count(*) from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . ' )';
		} else {
			$query = 'select count(*) from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . ' ) AND (( moderate = "1" AND lower(post_status) = "yes") OR (moderate IS NULL or moderate ="")) ';
		}
		$feeds_stream = $wpdb->get_var( $query );
		if ( $feeds_stream ) {
			return $feeds_stream;
		} else {
			return '0';
		}
	}

	/**
	 * With out image
	 *
	 * @since  1.0.0
	 * @return string
	 */
	public function ssd_total_stream_without_image() {
		global $wpdb;
		$feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		$feed_id          = $this->feed_id;
		if ( is_user_logged_in() ) {
			$query = 'select count(*) from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . " ) and post_image !='' ";
		} else {
			$query = 'select count(*) from ' . $feed_posts_table . ' where feed_id in ( ' . $feed_id . ' ) and post_image !="" AND (( moderate = "1" AND lower(post_status) = "yes") OR (moderate IS NULL or moderate ="")) ';
		}
		$feeds_stream = $wpdb->get_var( $query );
		if ( $feeds_stream ) {
			return $feeds_stream;
		} else {
			return '0';
		}
	}

}
